You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by da...@apache.org on 2005/12/13 09:25:59 UTC

svn commit: r356513 [1/2] - in /webservices/axis2/trunk/c: ides/anjuta/ include/ modules/core/context/src/ modules/core/deployment/src/ modules/core/description/src/ modules/core/engine/src/ modules/core/phaseresolver/src/ modules/wsdl/src/ test/unit/c...

Author: damitha
Date: Tue Dec 13 00:24:29 2005
New Revision: 356513

URL: http://svn.apache.org/viewcvs?rev=356513&view=rev
Log:
OPERATION to OP ENGINE_CONFIG to CONF INPHASE to IN_PHASE OUTPHASE to OUT_PHASE

Modified:
    webservices/axis2/trunk/c/ides/anjuta/axis2c.prj
    webservices/axis2/trunk/c/include/axis2.h
    webservices/axis2/trunk/c/include/axis2_conf.h
    webservices/axis2/trunk/c/include/axis2_conf_ctx.h
    webservices/axis2/trunk/c/include/axis2_disp.h
    webservices/axis2/trunk/c/include/axis2_error.h
    webservices/axis2/trunk/c/include/axis2_module_desc.h
    webservices/axis2/trunk/c/include/axis2_msg_ctx.h
    webservices/axis2/trunk/c/include/axis2_op.h
    webservices/axis2/trunk/c/include/axis2_op_ctx.h
    webservices/axis2/trunk/c/include/axis2_phase_resolver.h
    webservices/axis2/trunk/c/include/axis2_phases_info.h
    webservices/axis2/trunk/c/include/axis2_svc.h
    webservices/axis2/trunk/c/include/axis2_svc_ctx.h
    webservices/axis2/trunk/c/include/axis2_transport_in_desc.h
    webservices/axis2/trunk/c/include/axis2_transport_out_desc.h
    webservices/axis2/trunk/c/include/axis2_wsdl_binding.h
    webservices/axis2/trunk/c/include/axis2_wsdl_binding_op.h
    webservices/axis2/trunk/c/include/axis2_wsdl_interface.h
    webservices/axis2/trunk/c/include/axis2_wsdl_op.h
    webservices/axis2/trunk/c/include/axis2_wsdl_soap_op.h
    webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c
    webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c
    webservices/axis2/trunk/c/modules/core/context/src/op_ctx.c
    webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c
    webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c
    webservices/axis2/trunk/c/modules/core/deployment/src/phases_info.c
    webservices/axis2/trunk/c/modules/core/description/src/axis2_description.h
    webservices/axis2/trunk/c/modules/core/description/src/module_desc.c
    webservices/axis2/trunk/c/modules/core/description/src/op.c
    webservices/axis2/trunk/c/modules/core/description/src/svc.c
    webservices/axis2/trunk/c/modules/core/description/src/svc_grp.c
    webservices/axis2/trunk/c/modules/core/engine/src/addr_disp.c
    webservices/axis2/trunk/c/modules/core/engine/src/conf.c
    webservices/axis2/trunk/c/modules/core/engine/src/disp.c
    webservices/axis2/trunk/c/modules/core/engine/src/disp_checker.c
    webservices/axis2/trunk/c/modules/core/engine/src/engine.c
    webservices/axis2/trunk/c/modules/core/engine/src/req_uri_disp.c
    webservices/axis2/trunk/c/modules/core/engine/src/soap_action_disp.c
    webservices/axis2/trunk/c/modules/core/phaseresolver/src/phase_resolver.c
    webservices/axis2/trunk/c/modules/wsdl/src/axis2_wsdl.h
    webservices/axis2/trunk/c/modules/wsdl/src/wsdl_binding.c
    webservices/axis2/trunk/c/modules/wsdl/src/wsdl_binding_op.c
    webservices/axis2/trunk/c/modules/wsdl/src/wsdl_interface.c
    webservices/axis2/trunk/c/modules/wsdl/src/wsdl_soap_op.c
    webservices/axis2/trunk/c/test/unit/core/description/test_op.c
    webservices/axis2/trunk/c/test/unit/core/description/test_op.h
    webservices/axis2/trunk/c/test/unit/core/phaseresolver/test_resolver.c

Modified: webservices/axis2/trunk/c/ides/anjuta/axis2c.prj
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/ides/anjuta/axis2c.prj?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/ides/anjuta/axis2c.prj (original)
+++ webservices/axis2/trunk/c/ides/anjuta/axis2c.prj Tue Dec 13 00:24:29 2005
@@ -300,7 +300,11 @@
 	modules/core/context/src/op_ctx.c\
 	modules/wsdl/src/wsdl_binding_op.c\
 	modules/wsdl/src/wsdl_op.c\
-	modules/wsdl/src/wsdl_soap_op.c
+	modules/wsdl/src/wsdl_soap_op.c\
+	test/unit/core/description/test_op.c\
+	test/unit/core/description/test_op.h\
+	test/unit/core/description/test_svc.c\
+	test/unit/core/description/test_svc.h
 
 module.pixmap.name=.
 module.pixmap.type=

Modified: webservices/axis2/trunk/c/include/axis2.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2.h (original)
+++ webservices/axis2/trunk/c/include/axis2.h Tue Dec 13 00:24:29 2005
@@ -98,9 +98,9 @@
 typedef enum axis2_op_type
 {
     /** axis2_wsdl_op */
-    AXIS2_WSDL_OPERATION = 0,
+    AXIS2_WSDL_OP = 0,
     /** axis2_op */
-    AXIS2_OPERATION
+    AXIS2_OP
     
 }axis2_op_type_t;
 
@@ -245,7 +245,7 @@
 
 /* static const axis2_char_t * PHASE_LIST = "phaseList"; */
 
-/* static const axis2_char_t * LIST_OPERATIONS_FOR_THE_SERVICE = "listOperations"; */
+/* static const axis2_char_t * LIST_OPS_FOR_THE_SERVICE = "listOperations"; */
 
 /* static const axis2_char_t * REMOVE_SERVICE = "removeService"; */
 
@@ -307,7 +307,7 @@
 
 /*************************** REST_WITH_GET ************************************/
 
-/* static const axis2_char_t * GET_PARAMETER_OPERATION = "op"; */
+/* static const axis2_char_t * GET_PARAMETER_OP = "op"; */
 /* static const axis2_char_t * GET_PARAMETER_URL = "http://ws.apache.org/goGetWithREST"; */
 
 /******************************************************************************/

Modified: webservices/axis2/trunk/c/include/axis2_conf.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_conf.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_conf.h (original)
+++ webservices/axis2/trunk/c/include/axis2_conf.h Tue Dec 13 00:24:29 2005
@@ -293,113 +293,113 @@
 
 /************************* Start of function macros	***************************/
 	
-#define AXIS2_ENGINE_CONFIG_FREE(conf, env) \
+#define AXIS2_CONF_FREE(conf, env) \
 		(conf->ops->free(conf, env))
 	
-#define AXIS2_ENGINE_CONFIG_ADD_SVC_GRP(conf, env, svc_grp) \
+#define AXIS2_CONF_ADD_SVC_GRP(conf, env, svc_grp) \
         (conf->ops->add_svc_grp (conf, env, svc_grp))
 
-#define AXIS2_ENGINE_CONFIG_GET_SVC_GRP(conf, env, svc_grp_name) \
+#define AXIS2_CONF_GET_SVC_GRP(conf, env, svc_grp_name) \
         (conf->ops->get_svc_grp (conf, env, svc_grp_name))
 
-#define AXIS2_ENGINE_CONFIG_GET_SVC_GRPS(conf, env) \
+#define AXIS2_CONF_GET_SVC_GRPS(conf, env) \
         (conf->ops->get_svc_grps (conf, env))
 
-#define AXIS2_ENGINE_CONFIG_ADD_SVC(conf, env, svc) \
+#define AXIS2_CONF_ADD_SVC(conf, env, svc) \
 		(conf->ops->get_svc (conf, env, svc))
 		
-#define AXIS2_ENGINE_CONFIG_GET_SVC(conf, env, svc_name) \
+#define AXIS2_CONF_GET_SVC(conf, env, svc_name) \
 		(conf->ops->get_svc (conf, env, svc_name))
 
-#define AXIS2_ENGINE_CONFIG_REMOVE_SVC(conf, env, svc_name) \
+#define AXIS2_CONF_REMOVE_SVC(conf, env, svc_name) \
 		(conf->ops->remove_svc (conf, env, svc_name))
         
-#define AXIS2_ENGINE_CONFIG_ADD_PARAM(conf, env, param) \
+#define AXIS2_CONF_ADD_PARAM(conf, env, param) \
         (conf->ops->add_param(conf , env, param))
 		
-#define AXIS2_ENGINE_CONFIG_GET_PARAM(conf, env, name) \
+#define AXIS2_CONF_GET_PARAM(conf, env, name) \
         (conf->ops->get_param(conf , env, name))
 		
-#define AXIS2_ENGINE_CONFIG_GET_PARAMS(conf, env) \
+#define AXIS2_CONF_GET_PARAMS(conf, env) \
         (conf->ops->get_params(conf , env))
 		
-#define AXIS2_ENGINE_CONFIG_IS_PARAM_LOCKED(conf, env, param_name) \
+#define AXIS2_CONF_IS_PARAM_LOCKED(conf, env, param_name) \
         (conf->ops->is_param_locked(conf, env, param_name))
 
-#define AXIS2_ENGINE_CONFIG_GET_TRANSPORT_IN(conf, env, qname) \
+#define AXIS2_CONF_GET_TRANSPORT_IN(conf, env, qname) \
         (conf->ops->get_transport_in(conf , env, qname))
 
-#define AXIS2_ENGINE_CONFIG_ADD_TRANSPORT_IN(conf, env, transport) \
+#define AXIS2_CONF_ADD_TRANSPORT_IN(conf, env, transport) \
         (conf->ops->add_transport_in(conf , env, transport))
 
-#define AXIS2_ENGINE_CONFIG_GET_TRANSPORT_OUT(conf, env, qname) \
+#define AXIS2_CONF_GET_TRANSPORT_OUT(conf, env, qname) \
         (conf->ops->get_transport_out(conf , env, qname))
 
-#define AXIS2_ENGINE_CONFIG_ADD_TRANSPORT_OUT(conf, env, transport) \
+#define AXIS2_CONF_ADD_TRANSPORT_OUT(conf, env, transport) \
         (conf->ops->add_transport_out(conf , env, transport))
  
-#define AXIS2_ENGINE_CONFIG_GET_TRANSPORTS_IN(conf, env) \
+#define AXIS2_CONF_GET_TRANSPORTS_IN(conf, env) \
         (conf->ops->get_transports_in(conf , env)) 
  
-#define AXIS2_ENGINE_CONFIG_GET_TRANSPORTS_OUT(conf, env) \
+#define AXIS2_CONF_GET_TRANSPORTS_OUT(conf, env) \
         (conf->ops->get_transports_out(conf , env)) 
  
-#define AXIS2_ENGINE_CONFIG_GET_MODULE(conf, env, qname) \
+#define AXIS2_CONF_GET_MODULE(conf, env, qname) \
         (conf->ops->get_module(conf , env, qname)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_ENGAGED_MODULES(conf, env) \
+#define AXIS2_CONF_GET_ENGAGED_MODULES(conf, env) \
         (conf->ops->get_engaged_modules(conf , env)) 
         
-#define AXIS2_ENGINE_CONFIG_GET_IN_PHASES_UPTO_AND_INCLUDING_POST_DISPATCH(conf, env) \
+#define AXIS2_CONF_GET_IN_PHASES_UPTO_AND_INCLUDING_POST_DISPATCH(conf, env) \
         (conf->ops->get_in_phases_upto_and_including_post_dispatch(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_OUTFLOW(conf, env) \
+#define AXIS2_CONF_GET_OUTFLOW(conf, env) \
         (conf->ops->get_outflow(conf , env)) 
         
-#define AXIS2_ENGINE_CONFIG_GET_IN_FAULT_FLOW(conf, env) \
+#define AXIS2_CONF_GET_IN_FAULT_FLOW(conf, env) \
         (conf->ops->get_in_faultflow(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_OUT_FAULT_FLOW(conf, env) \
+#define AXIS2_CONF_GET_OUT_FAULT_FLOW(conf, env) \
         (conf->ops->get_out_faultflow(conf , env)) 
 
 
-#define AXIS2_ENGINE_CONFIG_GET_FAULTY_SVCS(conf, env) \
+#define AXIS2_CONF_GET_FAULTY_SVCS(conf, env) \
         (conf->ops->get_faulty_svcs(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_FAULTY_MODULES(conf, env) \
+#define AXIS2_CONF_GET_FAULTY_MODULES(conf, env) \
         (conf->ops->get_faulty_modules(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_SVCS(conf, env) \
+#define AXIS2_CONF_GET_SVCS(conf, env) \
         (conf->ops->get_svcs(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_IS_ENGAGED(conf, env, module_name) \
+#define AXIS2_CONF_IS_ENGAGED(conf, env, module_name) \
         (conf->ops->is_engaged(conf , env, module_name)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_PHASESINFO(conf, env) \
+#define AXIS2_CONF_GET_PHASESINFO(conf, env) \
         (conf->ops->get_phases_info(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_SET_PHASESINFO(conf, env, phases_info) \
+#define AXIS2_CONF_SET_PHASESINFO(conf, env, phases_info) \
         (conf->ops->set_phases_info(conf , env, phases_info)) 
 
-#define AXIS2_ENGINE_CONFIG_ADD_MSG_RECV(conf, env, key, msg_recv) \
+#define AXIS2_CONF_ADD_MSG_RECV(conf, env, key, msg_recv) \
         (conf->ops->add_msg_recv(conf , env, key, msg_recv)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_MSG_RECV(conf, env, key) \
+#define AXIS2_CONF_GET_MSG_RECV(conf, env, key) \
         (conf->ops->get_msg_recv(conf , env, key)) 
 
-#define AXIS2_ENGINE_CONFIG_SET_OUTPHASES(conf, env, out_phases) \
+#define AXIS2_CONF_SET_OUT_PHASES(conf, env, out_phases) \
         (conf->ops->set_out_phases(conf , env, out_phases)) 
 
-#define AXIS2_ENGINE_CONFIG_SET_IN_FAULTPHASES(conf, env, list) \
+#define AXIS2_CONF_SET_IN_FAULTPHASES(conf, env, list) \
         (conf->ops->set_in_faultphases(conf , env, list)) 
 
-#define AXIS2_ENGINE_CONFIG_SET_OUT_FAULTPHASES(conf, env, list) \
+#define AXIS2_CONF_SET_OUT_FAULTPHASES(conf, env, list) \
         (conf->ops->set_out_faultphases(conf , env, list)) 
 
-#define AXIS2_ENGINE_CONFIG_GET_MODULES(conf, env) \
+#define AXIS2_CONF_GET_MODULES(conf, env) \
         (conf->ops->get_modules(conf , env)) 
 
-#define AXIS2_ENGINE_CONFIG_ADD_MODULE(conf, env, module) \
+#define AXIS2_CONF_ADD_MODULE(conf, env, module) \
         (conf->ops->add_module(conf , env, module)) 
         
 /************************* End of function macros *****************************/

Modified: webservices/axis2/trunk/c/include/axis2_conf_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_conf_ctx.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_conf_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_conf_ctx.h Tue Dec 13 00:24:29 2005
@@ -175,14 +175,14 @@
     
 /************************** Start of function macros **************************/
 
-#define AXIS2_CONF_CTX_SET_ENGINE_CONFIG(conf_ctx, env, conf) ((conf_ctx)->ops->set_conf(conf_ctx, env, conf))
+#define AXIS2_CONF_CTX_SET_CONF(conf_ctx, env, conf) ((conf_ctx)->ops->set_conf(conf_ctx, env, conf))
 #define AXIS2_CONF_CTX_GET_BASE(conf_ctx, env) ((conf_ctx)->ops->get_base(conf_ctx, env))
-#define AXIS2_CONF_CTX_GET_ENGINE_CONFIG(conf_ctx, env) ((conf_ctx)->ops->get_conf(conf_ctx, env))
-#define AXIS2_CONF_CTX_GET_OPERATION_CTX_MAP(conf_ctx, env) ((conf_ctx)->ops->get_op_ctx_map(conf_ctx, env))
+#define AXIS2_CONF_CTX_GET_CONF(conf_ctx, env) ((conf_ctx)->ops->get_conf(conf_ctx, env))
+#define AXIS2_CONF_CTX_GET_OP_CTX_MAP(conf_ctx, env) ((conf_ctx)->ops->get_op_ctx_map(conf_ctx, env))
 #define AXIS2_CONF_CTX_GET_SVC_CTX_MAP(conf_ctx, env) ((conf_ctx)->ops->get_svc_ctx_map(conf_ctx, env))
 #define AXIS2_CONF_CTX_GET_SVC_GRP_CTX_MAP(conf_ctx, env) ((conf_ctx)->ops->get_svc_grp_ctx_map(conf_ctx, env))
-#define AXIS2_CONF_CTX_REGISTER_OPERATION_CTX(conf_ctx, env, message_id, op_ctx) ((conf_ctx)->ops->register_op_ctx(conf_ctx, env, message_id, op_ctx))
-#define AXIS2_CONF_CTX_GET_OPERATION_CTX(conf_ctx, env, message_id) ((conf_ctx)->ops->get_op_ctx(conf_ctx, env, message_id))
+#define AXIS2_CONF_CTX_REGISTER_OP_CTX(conf_ctx, env, message_id, op_ctx) ((conf_ctx)->ops->register_op_ctx(conf_ctx, env, message_id, op_ctx))
+#define AXIS2_CONF_CTX_GET_OP_CTX(conf_ctx, env, message_id) ((conf_ctx)->ops->get_op_ctx(conf_ctx, env, message_id))
 #define AXIS2_CONF_CTX_REGISTER_SVC_CTX(conf_ctx, env, svc_id, svc_ctx) ((conf_ctx)->ops->register_svc_ctx(conf_ctx, env, svc_id, svc_ctx))
 #define AXIS2_CONF_CTX_GET_SVC_CTX(conf_ctx, env, svc_id) ((conf_ctx)->ops->get_svc_ctx(conf_ctx, env, svc_id))
 #define AXIS2_CONF_CTX_REGISTER_SVC_GRP_CTX(conf_ctx, env, svc_grp_id, svc_grp_ctx) ((conf_ctx)->ops->register_svc_grp_ctx(conf_ctx, env, svc_grp_id, svc_grp_ctx))

Modified: webservices/axis2/trunk/c/include/axis2_disp.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_disp.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_disp.h (original)
+++ webservices/axis2/trunk/c/include/axis2_disp.h Tue Dec 13 00:24:29 2005
@@ -97,7 +97,7 @@
 #define AXIS2_DISP_SET_QNAME(disp, env, name) ((disp)->ops->set_qname(disp, env, name))
 #define AXIS2_DISP_FREE(disp, env) ((disp)->ops->free(disp, env))
 #define AXIS2_DISP_FIND_SVC(msg_ctx, env) ((msg_ctx)->ops->find_svc(msg_ctx, env))
-#define AXIS2_DISP_FIND_OPERATION(msg_ctx, env, svc) ((msg_ctx)->ops->find_op(msg_ctx, env, svc))
+#define AXIS2_DISP_FIND_OP(msg_ctx, env, svc) ((msg_ctx)->ops->find_op(msg_ctx, env, svc))
 
 axis2_status_t AXIS2_CALL axis2_disp_invoke(struct axis2_handler * handler, 
                                                 axis2_env_t **env,

Modified: webservices/axis2/trunk/c/include/axis2_error.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_error.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_error.h (original)
+++ webservices/axis2/trunk/c/include/axis2_error.h Tue Dec 13 00:24:29 2005
@@ -160,7 +160,7 @@
         /** Parameter not set */
         AXIS2_ERROR_INVALID_STATE_PARAM,
         /** Operation accessed has invalid state */
-        AXIS2_ERROR_INVALID_STATE_OPERATION,
+        AXIS2_ERROR_INVALID_STATE_OP,
         /** Service accessed has invalid state */
         AXIS2_ERROR_INVALID_STATE_SVC,
         /** Wsdl Service accessed has invalid state */
@@ -168,7 +168,7 @@
         /** Service group accessed has invalid state */
         AXIS2_ERROR_INVALID_STATE_SVC_GRP,
         /** Wsdl op accessed has invalid state */
-        AXIS2_ERROR_INVALID_STATE_WSDL_OPERATION,
+        AXIS2_ERROR_INVALID_STATE_WSDL_OP,
         /** Module description accessed has invalid state */
         AXIS2_ERROR_INVALID_STATE_MODULE_DESC,
         /** Array list index out of bounds */
@@ -194,7 +194,7 @@
         /** Could not Map the MEP URI to a axis MEP constant value */
         AXIS2_ERROR_COULD_NOT_MAP_MEP_URI_TO_MEP_CONSTANT,
         /** module has alredy engaged to the op op terminated !!! */
-        AXIS2_ERROR_MODULE_ALREADY_ENGAGED_TO_OPERATION,
+        AXIS2_ERROR_MODULE_ALREADY_ENGAGED_TO_OP,
         /** module has alredy been engaged on the service.Operation terminated !!! */
         AXIS2_ERROR_MODULE_ALREADY_ENGAGED_TO_SVC,
         /** module has alredy been engaged on the service. Group Operation terminated !!! */
@@ -202,7 +202,7 @@
         /** Invalid message context state  */
         AXIS2_ERROR_INVALID_STATE_MSG_CTX,
         /** Invalid engine config state */
-        AXIS2_ERROR_INVALID_STATE_ENGINE_CONFIG,
+        AXIS2_ERROR_INVALID_STATE_CONF,
         /** Service not yet found */
         AXIS2_ERROR_SERVICE_NOT_YET_FOUND,
         /** error occured creating xml stream writer */

Modified: webservices/axis2/trunk/c/include/axis2_module_desc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_module_desc.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_module_desc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_module_desc.h Tue Dec 13 00:24:29 2005
@@ -276,10 +276,10 @@
 #define AXIS2_MODULE_DESC_SET_NAME(module_desc, env, qname) \
         (module_desc->ops->set_name(module_desc, env, qname))
 
-#define AXIS2_MODULE_DESC_ADD_OPERATION(module_desc, env, op) \
+#define AXIS2_MODULE_DESC_ADD_OP(module_desc, env, op) \
         (module_desc->ops->add_op(module_desc, env, op))
         
-#define AXIS2_MODULE_DESC_GET_OPERATIONS(module_desc, env) \
+#define AXIS2_MODULE_DESC_GET_OPS(module_desc, env) \
         (module_desc->ops->get_ops(module_desc, env))
 
 #define AXIS2_MODULE_DESC_GET_PARENT(module_desc, env) \

Modified: webservices/axis2/trunk/c/include/axis2_msg_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_msg_ctx.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_msg_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_msg_ctx.h Tue Dec 13 00:24:29 2005
@@ -661,8 +661,8 @@
 #define AXIS2_MSG_CTX_GET_TRANSPORT_OUT_DESC(msg_ctx, env) ((msg_ctx)->ops->get_transport_out_desc(msg_ctx, env))
 #define AXIS2_MSG_CTX_SET_TRANSPORT_IN_DESC(msg_ctx, env, transport_in_desc) ((msg_ctx)->ops->set_transport_in_desc(msg_ctx, env, transport_in_desc))
 #define AXIS2_MSG_CTX_SET_TRANSPORT_OUT_DESC(msg_ctx, env, transport_out_desc) ((msg_ctx)->ops->set_transport_out_desc(msg_ctx, env, transport_out_desc))
-#define AXIS2_MSG_CTX_GET_OPERATION_CTX(msg_ctx, env) ((msg_ctx)->ops->get_op_ctx(msg_ctx, env))
-#define AXIS2_MSG_CTX_SET_OPERATION_CTX(msg_ctx, env, op_ctx) ((msg_ctx)->ops->set_op_ctx(msg_ctx, env, op_ctx))
+#define AXIS2_MSG_CTX_GET_OP_CTX(msg_ctx, env) ((msg_ctx)->ops->get_op_ctx(msg_ctx, env))
+#define AXIS2_MSG_CTX_SET_OP_CTX(msg_ctx, env, op_ctx) ((msg_ctx)->ops->set_op_ctx(msg_ctx, env, op_ctx))
 #define AXIS2_MSG_CTX_GET_OUTPUT_WRITTEN(msg_ctx, env) ((msg_ctx)->ops->get_output_written(msg_ctx, env))
 #define AXIS2_MSG_CTX_SET_OUTPUT_WRITTEN(msg_ctx, env, output_written) ((msg_ctx)->ops->set_output_written(msg_ctx, env, output_written))
 #define AXIS2_MSG_CTX_GET_SVC_CTX_ID(msg_ctx, env) ((msg_ctx)->ops->get_svc_ctx_id(msg_ctx, env))
@@ -688,8 +688,8 @@
 #define AXIS2_MSG_CTX_GET_IS_SOAP_11(msg_ctx, env) ((msg_ctx)->ops->get_is_soap_11(msg_ctx, env))
 #define AXIS2_MSG_CTX_GET_SVC_GRP_CTX(msg_ctx, env) ((msg_ctx)->ops->get_svc_grp_ctx(msg_ctx, env))
 #define AXIS2_MSG_CTX_SET_SVC_GRP_CTX(msg_ctx, env, svc_grp_ctx) ((msg_ctx)->ops->set_svc_grp_ctx(msg_ctx, env, svc_grp_ctx))
-#define AXIS2_MSG_CTX_GET_OPERATION(msg_ctx, env) ((msg_ctx)->ops->get_op(msg_ctx, env))
-#define AXIS2_MSG_CTX_SET_OPERATION(msg_ctx, env, op) ((msg_ctx)->ops->set_op(msg_ctx, env, op))
+#define AXIS2_MSG_CTX_GET_OP(msg_ctx, env) ((msg_ctx)->ops->get_op(msg_ctx, env))
+#define AXIS2_MSG_CTX_SET_OP(msg_ctx, env, op) ((msg_ctx)->ops->set_op(msg_ctx, env, op))
 #define AXIS2_MSG_CTX_GET_SVC(msg_ctx, env) ((msg_ctx)->ops->get_svc(msg_ctx, env))
 #define AXIS2_MSG_CTX_SET_SVC(msg_ctx, env, svc) ((msg_ctx)->ops->set_svc(msg_ctx, env, svc))
 #define AXIS2_MSG_CTX_GET_SVC_GRP(msg_ctx, env) ((msg_ctx)->ops->get_svc_grp(msg_ctx, env))
@@ -698,7 +698,7 @@
 #define AXIS2_MSG_CTX_SET_SVC_GRP_CTX_ID(msg_ctx, env, svc_grp_ctx_id) ((msg_ctx)->ops->set_svc_grp_ctx_id(msg_ctx, env, svc_grp_ctx_id))
 #define AXIS2_MSG_CTX_IS_PAUSED(msg_ctx, env) ((msg_ctx)->ops->is_paused(msg_ctx, env))
 #define AXIS2_MSG_CTX_FIND_SVC(msg_ctx, env) ((msg_ctx)->ops->find_svc(msg_ctx, env))
-#define AXIS2_MSG_CTX_FIND_OPERATION(msg_ctx, env, svc) ((msg_ctx)->ops->find_op(msg_ctx, env, svc))
+#define AXIS2_MSG_CTX_FIND_OP(msg_ctx, env, svc) ((msg_ctx)->ops->find_op(msg_ctx, env, svc))
 
 /************************** End of function macros ****************************/    
 

Modified: webservices/axis2/trunk/c/include/axis2_op.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_op.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_op.h (original)
+++ webservices/axis2/trunk/c/include/axis2_op.h Tue Dec 13 00:24:29 2005
@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#ifndef AXIS2_OPERATION_H
-#define AXIS2_OPERATION_H
+#ifndef AXIS2_OP_H
+#define AXIS2_OP_H
 
 /**
   * @file axis2_op.h
@@ -362,147 +362,147 @@
 
 /************************** Start of function macros **************************/
 
-#define AXIS2_OPERATION_FREE(op, env) \
+#define AXIS2_OP_FREE(op, env) \
         ((op->ops)->free (op, env))
 
-#define AXIS2_OPERATION_ADD_PARAM(op, env, param) \
+#define AXIS2_OP_ADD_PARAM(op, env, param) \
 		((op->ops)->add_param (op, env, param))
 
-#define AXIS2_OPERATION_GET_PARAM(op, env) \
+#define AXIS2_OP_GET_PARAM(op, env) \
 		((op->ops)->get_param (op, env))
 
-#define AXIS2_OPERATION_GET_PARAMS(op, env) \
+#define AXIS2_OP_GET_PARAMS(op, env) \
 		((op->ops)->get_params (op, env))
 
-#define AXIS2_OPERATION_IS_PARAM_LOCKED(op, env, param_name) \
+#define AXIS2_OP_IS_PARAM_LOCKED(op, env, param_name) \
         ((op->ops)->is_param_locked(op, env, param_name))
 
-#define AXIS2_OPERATION_SET_PARENT(op, env, service_desc) \
+#define AXIS2_OP_SET_PARENT(op, env, service_desc) \
         ((op->ops)->set_parent (op, env, service_desc))
 
-#define AXIS2_OPERATION_GET_PARENT(op, env) \
+#define AXIS2_OP_GET_PARENT(op, env) \
 		((op->ops)->get_parent (op, env))
 
-#define AXIS2_OPERATION_SET_MSG_RECEIVER(op, env, msg_recv) \
+#define AXIS2_OP_SET_MSG_RECEIVER(op, env, msg_recv) \
         ((op->ops)->set_msg_recv (op, env, msg_recv))
 
-#define AXIS2_OPERATION_GET_MSG_RECEIVER(op, env) \
+#define AXIS2_OP_GET_MSG_RECEIVER(op, env) \
 		((op->ops)->get_msg_recv (op, env))
 
-#define AXIS2_OPERATION_SET_NAME(op, env, qname) \
+#define AXIS2_OP_SET_NAME(op, env, qname) \
 		((op->ops)->set_name (op, env, qname))
         
-#define AXIS2_OPERATION_GET_NAME(op, env) \
+#define AXIS2_OP_GET_NAME(op, env) \
 		((op->ops)->get_name (op, env))
 
-#define AXIS2_OPERATION_SET_MSG_EXCHANGE_PATTERN(op , env, \
+#define AXIS2_OP_SET_MSG_EXCHANGE_PATTERN(op , env, \
         msg_exchange_pattern) \
 		((op->ops)->set_msg_exchange_pattern (op, env, \
         msg_exchange_pattern))
 
-#define AXIS2_OPERATION_GET_MSG_EXCHANGE_PATTERN(op, env) \
+#define AXIS2_OP_GET_MSG_EXCHANGE_PATTERN(op, env) \
 		((op->ops)->get_msg_exchange_pattern (op, env))
         
-#define AXIS2_OPERATION_GET_STYLE(op, env) \
+#define AXIS2_OP_GET_STYLE(op, env) \
 		((op->ops)->get_style (op, env))
         
-#define AXIS2_OPERATION_SET_STYLE(op, env, style) \
+#define AXIS2_OP_SET_STYLE(op, env, style) \
 		((op->ops)->set_style (op, env, style))   
 
-#define AXIS2_OPERATION_ENGAGE_MODULE(op, env, moduleref) \
+#define AXIS2_OP_ENGAGE_MODULE(op, env, moduleref) \
 		((op->ops)->engage_module (op, env, moduleref))
         
-#define AXIS2_OPERATION_ADD_TO_ENGAGE_MODULE_LIST(op, env, module_name) \
+#define AXIS2_OP_ADD_TO_ENGAGE_MODULE_LIST(op, env, module_name) \
 		((op->ops)->add_to_engage_module_list (op, env, module_name))
 
-#define AXIS2_OPERATION_GET_MODULES(op, env) \
+#define AXIS2_OP_GET_MODULES(op, env) \
 		((op->ops)->get_modules (op, env))
         
-#define AXIS2_OPERATION_GET_AXIS_SPECIFIC_MEP_CONSTANT(op, env) \
+#define AXIS2_OP_GET_AXIS_SPECIFIC_MEP_CONSTANT(op, env) \
 		((op->ops)->get_axis_specific_MEP_constant (op, env))
 
-#define AXIS2_OPERATION_GET_PHASES_IN_FAULT_FLOW(op, env) \
+#define AXIS2_OP_GET_PHASES_IN_FAULT_FLOW(op, env) \
 		((op->ops)->get_phases_in_fault_flow (op, env))
         
-#define AXIS2_OPERATION_GET_PHASES_OUT_FAULT_FLOW(op, env) \
+#define AXIS2_OP_GET_PHASES_OUT_FAULT_FLOW(op, env) \
 		((op->ops)->get_phases_out_fault_flow (op, env))
 
-#define AXIS2_OPERATION_GET_PHASES_OUTFLOW(op, env) \
+#define AXIS2_OP_GET_PHASES_OUTFLOW(op, env) \
 		((op->ops)->get_phases_outflow (op, env))
  
-#define AXIS2_OPERATION_GET_REMAINING_PHASES_INFLOW(op, env) \
+#define AXIS2_OP_GET_REMAINING_PHASES_INFLOW(op, env) \
 		((op->ops)->get_remaining_phases_inflow (op, env))    
 
-#define AXIS2_OPERATION_SET_PHASES_IN_FAULT_FLOW(op, env, list) \
+#define AXIS2_OP_SET_PHASES_IN_FAULT_FLOW(op, env, list) \
 		((op->ops)->set_phases_in_fault_flow (op, env, list))    
 
-#define AXIS2_OPERATION_SET_PHASES_OUT_FAULT_FLOW(op, env, list) \
+#define AXIS2_OP_SET_PHASES_OUT_FAULT_FLOW(op, env, list) \
 		((op->ops)->set_phases_out_fault_flow (op, env, list))   
 
-#define AXIS2_OPERATION_SET_PHASES_OUTFLOW(op, env, list) \
+#define AXIS2_OP_SET_PHASES_OUTFLOW(op, env, list) \
 		((op->ops)->set_phases_outflow (op, env, list)) 
         
-#define AXIS2_OPERATION_SET_REMAINING_PHASES_INFLOW(op, env, list) \
+#define AXIS2_OP_SET_REMAINING_PHASES_INFLOW(op, env, list) \
 		((op->ops)->set_remaining_phases_inflow (op, env, list))
         
-#define AXIS2_OPERATION_ADD_MODULE(op, env, module_name) \
+#define AXIS2_OP_ADD_MODULE(op, env, module_name) \
 		((op->ops)->add_module (op, env, module_name))
 
-#define AXIS2_OPERATION_GET_MODULE_REFS(op, env) \
+#define AXIS2_OP_GET_MODULE_REFS(op, env) \
 		((op->ops)->get_module_refs (op, env))
         
-#define AXIS2_OPERATION_GET_INFAULTS(op, env) \
+#define AXIS2_OP_GET_IN_FAULTS(op, env) \
 		((op->ops)->get_in_faults (op, env))
 
-#define AXIS2_OPERATION_SET_INFAULTS(op, env) \
+#define AXIS2_OP_SET_IN_FAULTS(op, env) \
 		((op->ops)->set_in_faults (op, env, in_faults))
         
-#define AXIS2_OPERATION_GET_INPUT_MSG(op, env) \
+#define AXIS2_OP_GET_INPUT_MSG(op, env) \
 		((op->ops)->get_input_msg (op, env))
 
-#define AXIS2_OPERATION_SET_INPUT_MSG(op, env) \
+#define AXIS2_OP_SET_INPUT_MSG(op, env) \
 		((op->ops)->set_input_msg (op, env, input_msg))
         
-#define AXIS2_OPERATION_GET_OUTFAULTS(op, env) \
+#define AXIS2_OP_GET_OUTFAULTS(op, env) \
 		((op->ops)->get_out_faults (op, env))
 
-#define AXIS2_OPERATION_SET_OUTFAULTS(op, env) \
+#define AXIS2_OP_SET_OUTFAULTS(op, env) \
 		((op->ops)->set_out_faults (op, env, out_faults))
         
-#define AXIS2_OPERATION_GET_OUTPUT_MSG(op, env) \
+#define AXIS2_OP_GET_OUTPUT_MSG(op, env) \
 		((op->ops)->get_output_msg (op, env))
 
-#define AXIS2_OPERATION_SET_OUTPUT_MSG(op, env) \
+#define AXIS2_OP_SET_OUTPUT_MSG(op, env) \
 		((op->ops)->set_output_msg (op, env, output_msg))
         
-#define AXIS2_OPERATION_IS_SAFE(op, env) \
+#define AXIS2_OP_IS_SAFE(op, env) \
 		((op->ops)->is_safe (op, env))
 
-#define AXIS2_OPERATION_SET_SAFETY(op, env, safe) \
+#define AXIS2_OP_SET_SAFETY(op, env, safe) \
 		((op->ops)->set_safety (op, env, safe))
         
-#define AXIS2_OPERATION_GET_TARGET_NAMESPACE(op, env) \
+#define AXIS2_OP_GET_TARGET_NAMESPACE(op, env) \
 		((op->ops)->get_target_namespace (op, env))
 
-#define AXIS2_OPERATION_ADD_INFAULT(op, env, in_fault) \
+#define AXIS2_OP_ADD_IN_FAULT(op, env, in_fault) \
 		((op->ops)->add_in_fault (op, env, in_fault))
         
-#define AXIS2_OPERATION_ADD_OUTFAULT(op, env, out_fault) \
+#define AXIS2_OP_ADD_OUTFAULT(op, env, out_fault) \
 		((op->ops)->add_out_fault (op, env, out_fault))
 
-#define AXIS2_OPERATION_ADD_FEATURE(op, env, feature) \
+#define AXIS2_OP_ADD_FEATURE(op, env, feature) \
 		((op->ops)->add_feature (op, env, feature))
         
-#define AXIS2_OPERATION_GET_FEATURES(op, env) \
+#define AXIS2_OP_GET_FEATURES(op, env) \
 		((op->ops)->get_features(op, env))
 
-#define AXIS2_OPERATION_ADD_PROPERTY(op, env, wsdl_property) \
+#define AXIS2_OP_ADD_PROPERTY(op, env, wsdl_property) \
 		((op->ops)->add_property (op, env, wsdl_property))
         
-#define AXIS2_OPERATION_GET_PROPERTIES(op, env) \
+#define AXIS2_OP_GET_PROPERTIES(op, env) \
 		((op->ops)->get_properties (op, env, properties))
 
-#define AXIS2_OPERATION_SET_WSDL_OPERATION(op, env) \
+#define AXIS2_OP_SET_WSDL_OP(op, env) \
 		((op->ops)->set_wsdl_opeartion (op, env))
 
 /************************** End of function macros ****************************/
@@ -511,4 +511,4 @@
 #ifdef __cplusplus
 }
 #endif
-#endif  /* AXIS2_OPERATION_H */
+#endif  /* AXIS2_OP_H */

Modified: webservices/axis2/trunk/c/include/axis2_op_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_op_ctx.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_op_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_op_ctx.h Tue Dec 13 00:24:29 2005
@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#ifndef AXIS2_OPERATION_CTX_H
-#define AXIS2_OPERATION_CTX_H
+#ifndef AXIS2_OP_CTX_H
+#define AXIS2_OP_CTX_H
 
 
 /**
@@ -149,18 +149,18 @@
     struct axis2_svc_ctx * svc_ctx);
     
 /************************** Start of function macros **************************/
-#define OPERATION_CTX_GET_BASE(op_ctx, env) ((op_ctx)->ops->get_base(op_ctx, env))
-#define AXIS2_OPERATION_CTX_FREE(op_ctx, env) ((op_ctx)->ops->free(op_ctx, env))
-#define AXIS2_OPERATION_CTX_INIT(op_ctx, env, conf) ((op_ctx)->ops->init(op_ctx, env, conf))
-#define AXIS2_OPERATION_CTX_GET_OPERATION(op_ctx, env) ((op_ctx)->ops->get_op(op_ctx, env))
-#define AXIS2_OPERATION_CTX_GET_PARENT(op_ctx, env) ((op_ctx)->ops->get_parent(op_ctx, env))
-#define AXIS2_OPERATION_CTX_ADD_MSG_CTX(op_ctx, env, msg_ctx) ((op_ctx)->ops->add_msg_ctx(op_ctx, env, msg_ctx))
-#define AXIS2_OPERATION_CTX_GET_MSG_CTX(op_ctx, env, message_id) ((op_ctx)->ops->get_msg_ctx(op_ctx, env, message_id))
-#define AXIS2_OPERATION_CTX_GET_IS_COMPLETE(op_ctx, env) ((op_ctx)->ops->get_is_complete(op_ctx, env))
-#define AXIS2_OPERATION_CTX_SET_IS_COMPLETE(op_ctx, env, is_complete) ((op_ctx)->ops->set_is_complete(op_ctx, env, is_complete))
-#define AXIS2_OPERATION_CTX_CLEANUP(op_ctx, env) ((op_ctx)->ops->cleanup(op_ctx, env))
-#define AXIS2_OPERATION_CTX_SET_PARENT(op_ctx, env, svc_ctx) ((op_ctx)->ops->set_parent(op_ctx, env, svc_ctx))
-#define AXIS2_OPERATION_CTX_GET_MSG_CTX_MAP(op_ctx, env) ((op_ctx)->ops->get_msg_ctx_map(op_ctx, env))    
+#define OP_CTX_GET_BASE(op_ctx, env) ((op_ctx)->ops->get_base(op_ctx, env))
+#define AXIS2_OP_CTX_FREE(op_ctx, env) ((op_ctx)->ops->free(op_ctx, env))
+#define AXIS2_OP_CTX_INIT(op_ctx, env, conf) ((op_ctx)->ops->init(op_ctx, env, conf))
+#define AXIS2_OP_CTX_GET_OP(op_ctx, env) ((op_ctx)->ops->get_op(op_ctx, env))
+#define AXIS2_OP_CTX_GET_PARENT(op_ctx, env) ((op_ctx)->ops->get_parent(op_ctx, env))
+#define AXIS2_OP_CTX_ADD_MSG_CTX(op_ctx, env, msg_ctx) ((op_ctx)->ops->add_msg_ctx(op_ctx, env, msg_ctx))
+#define AXIS2_OP_CTX_GET_MSG_CTX(op_ctx, env, message_id) ((op_ctx)->ops->get_msg_ctx(op_ctx, env, message_id))
+#define AXIS2_OP_CTX_GET_IS_COMPLETE(op_ctx, env) ((op_ctx)->ops->get_is_complete(op_ctx, env))
+#define AXIS2_OP_CTX_SET_IS_COMPLETE(op_ctx, env, is_complete) ((op_ctx)->ops->set_is_complete(op_ctx, env, is_complete))
+#define AXIS2_OP_CTX_CLEANUP(op_ctx, env) ((op_ctx)->ops->cleanup(op_ctx, env))
+#define AXIS2_OP_CTX_SET_PARENT(op_ctx, env, svc_ctx) ((op_ctx)->ops->set_parent(op_ctx, env, svc_ctx))
+#define AXIS2_OP_CTX_GET_MSG_CTX_MAP(op_ctx, env) ((op_ctx)->ops->get_msg_ctx_map(op_ctx, env))    
 
 /************************** End of function macros ****************************/    
 
@@ -169,4 +169,4 @@
 }
 #endif
 
-#endif                          /* AXIS2_OPERATION_CTX_H */
+#endif                          /* AXIS2_OP_CTX_H */

Modified: webservices/axis2/trunk/c/include/axis2_phase_resolver.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_phase_resolver.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_phase_resolver.h (original)
+++ webservices/axis2/trunk/c/include/axis2_phase_resolver.h Tue Dec 13 00:24:29 2005
@@ -185,7 +185,7 @@
 #define AXIS2_PHASE_RESOLVER_BUILD_CHAINS(phase_resolver, env) \
 		((phase_resolver->ops)->build_chains (phase_resolver, env))
 
-#define AXIS2_PHASE_RESOLVER_BUILD_MODULE_OPERATION(phase_resolver, env, op) \
+#define AXIS2_PHASE_RESOLVER_BUILD_MODULE_OP(phase_resolver, env, op) \
 		((phase_resolver->ops)->build_module_op (phase_resolver, env, op))
 
 #define AXIS2_PHASE_RESOLVER_BUILD_TRANSPORT_CHAINS(phase_resolver, env) \
@@ -200,7 +200,7 @@
 #define AXIS2_PHASE_RESOLVER_ENGAGE_MODULE_TO_SVC(phase_resolver, env, svc, module_desc) \
 		((phase_resolver->ops)->engage_module_to_svc (phase_resolver, env, svc, module_desc))
 
-#define AXIS2_PHASE_RESOLVER_ENGAGE_MODULE_TO_OPERATION(phase_resolver, env, axis_op, module_desc) \
+#define AXIS2_PHASE_RESOLVER_ENGAGE_MODULE_TO_OP(phase_resolver, env, axis_op, module_desc) \
 		((phase_resolver->ops)->engage_module_to_op (phase_resolver, env, axis_op, module_desc))
 
         

Modified: webservices/axis2/trunk/c/include/axis2_phases_info.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_phases_info.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_phases_info.h (original)
+++ webservices/axis2/trunk/c/include/axis2_phases_info.h Tue Dec 13 00:24:29 2005
@@ -121,10 +121,10 @@
 #define AXIS2_PHASES_INFO_FREE(phases_info, env) \
 		((phases_info->ops)->free (phases_info, env))
 
-#define AXIS2_PHASES_INFO_SET_INPHASES(phases_info, env, in_phases) \
+#define AXIS2_PHASES_INFO_SET_IN_PHASES(phases_info, env, in_phases) \
 		((phases_info->ops)->set_in_phases(phases_info, env, in_phases))
 		
-#define AXIS2_PHASES_INFO_SET_OUTPHASES(phases_info, env, out_phases) \
+#define AXIS2_PHASES_INFO_SET_OUT_PHASES(phases_info, env, out_phases) \
 		((phases_info->ops)->set_out_phases(phases_info, env, out_phases))
 
 #define AXIS2_PHASES_INFO_SET_IN_FAULTPHASES(phases_info, env, in_faultphases) \
@@ -133,10 +133,10 @@
 #define AXIS2_PHASES_INFO_SET_OUT_FAULTPHASES(phases_info, env, out_faultphases) \
 		((phases_info->ops)->set_out_faultphases(phases_info, env, out_faultphases)) 
 
-#define AXIS2_PHASES_INFO_GET_INPHASES(phases_info, env) \
+#define AXIS2_PHASES_INFO_GET_IN_PHASES(phases_info, env) \
 		((phases_info->ops)->get_in_phases(phases_info, env)) 
 
-#define AXIS2_PHASES_INFO_GET_OUTPHASES(phases_info, env) \
+#define AXIS2_PHASES_INFO_GET_OUT_PHASES(phases_info, env) \
 		((phases_info->ops)->get_out_phases(phases_info, env)) 
         
 #define AXIS2_PHASES_INFO_GET_IN_FAULTPHASES(phases_info, env) \
@@ -145,19 +145,19 @@
 #define AXIS2_PHASES_INFO_GET_OUT_FAULTPHASES(phases_info, env) \
 		((phases_info->ops)->get_out_faultphases(phases_info, env)) 
         
-#define AXIS2_PHASES_INFO_GET_OPERATION_INPHASES(phases_info, env) \
+#define AXIS2_PHASES_INFO_GET_OP_IN_PHASES(phases_info, env) \
 		((phases_info->ops)->get_op_in_phases(phases_info, env)) 
 
-#define AXIS2_PHASES_INFO_GET_OPERATION_OUTPHASES(phases_info, env) \
+#define AXIS2_PHASES_INFO_GET_OP_OUT_PHASES(phases_info, env) \
 		((phases_info->ops)->get_op_out_phases(phases_info, env)) 
                                         
-#define AXIS2_PHASES_INFO_GET_OPERATION_IN_FAULTPHASES(phases_info, env) \
+#define AXIS2_PHASES_INFO_GET_OP_IN_FAULTPHASES(phases_info, env) \
 		((phases_info->ops)->get_op_in_faultphases(phases_info, env))                                         
                                         
-#define AXIS2_PHASES_INFO_GET_OPERATION_OUT_FAULTPHASES(phases_info, env) \
+#define AXIS2_PHASES_INFO_GET_OP_OUT_FAULTPHASES(phases_info, env) \
 		((phases_info->ops)->get_op_out_faultphases(phases_info, env))                                         
                                         
-#define AXIS2_PHASES_INFO_SET_OPERATION_PHASES(phases_info, env, axis2_opt) \
+#define AXIS2_PHASES_INFO_SET_OP_PHASES(phases_info, env, axis2_opt) \
 		((phases_info->ops)->set_op_phases(phases_info, env, axis2_opt))                                         
                                            
 /**************************** End of function macros **************************/

Modified: webservices/axis2/trunk/c/include/axis2_svc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc.h Tue Dec 13 00:24:29 2005
@@ -447,16 +447,16 @@
 
 #define AXIS2_SVC_FREE(svc, env) (svc->ops->free (svc, env))
 
-#define AXIS2_SVC_ADD_OPERATION(svc, env, op) \
+#define AXIS2_SVC_ADD_OP(svc, env, op) \
 		(svc->ops->add_op (svc, env, op))
 
-#define AXIS2_SVC_GET_OPERATION_WITH_QNAME(svc, env, op_qname) \
+#define AXIS2_SVC_GET_OP_WITH_QNAME(svc, env, op_qname) \
 		(svc->ops->get_op_with_qname (svc, env, op_qname))
 
-#define AXIS2_SVC_GET_OPERATION_WITH_NAME(svc, env, op_name) \
+#define AXIS2_SVC_GET_OP_WITH_NAME(svc, env, op_name) \
 		(svc->ops->get_op_with_name (svc, env, op_name))
 
-#define AXIS2_SVC_GET_OPERATIONS(svc, env) (svc->ops->get_ops (svc, env))
+#define AXIS2_SVC_GET_OPS(svc, env) (svc->ops->get_ops (svc, env))
 
 #define AXIS2_SVC_SET_PARENT(svc, env , svc_grp) (svc->ops->set_parent \
         (svc, env, svc_grp))
@@ -485,7 +485,7 @@
 #define AXIS2_SVC_ENGAGE_MODULE(svc, env, moduleref, axis2_config) \
         (svc->ops->engage_module(svc, env, moduleref, axis2_config))
 
-#define AXIS2_SVC_ADD_MODULE_OPERATIONS(svc, env, module_desc, axis2_config) \
+#define AXIS2_SVC_ADD_MODULE_OPS(svc, env, module_desc, axis2_config) \
         (svc->ops->add_module_ops(svc, env, module_desc, axis2_config))
 
 #define AXIS2_SVC_ADD_TO_ENGAGED_MODULE_LIST(svc, env, module_name) \
@@ -494,7 +494,7 @@
 #define AXIS2_SVC_GET_ENGAGED_MODULES(svc, env) \
         (svc->ops->get_engaged_modules(svc, env))
 
-#define AXIS2_SVC_GET_WSDL_OPERATION(svc, env, op_name) \
+#define AXIS2_SVC_GET_WSDL_OP(svc, env, op_name) \
         (svc->ops->get_wsdl_op(svc, env, op_name))
 
 #define AXIS2_SVC_SET_CONTEXT_PATH(svc, env, context_path) \
@@ -533,10 +533,10 @@
 #define AXIS2_SVC_SET_FAULT_OUTFLOW(svc, env, fault_outflow) \
         (svc->ops->set_fault_outflow(svc, env, fault_outflow))
 
-#define AXIS2_SVC_GET_OPERATION_BY_SOAP_ACTION(svc, env, soap_action) \
+#define AXIS2_SVC_GET_OP_BY_SOAP_ACTION(svc, env, soap_action) \
         (svc->ops->get_op_by_soap_action(svc, env, soap_action))
 
-#define AXIS2_SVC_GET_OPERATION_BY_SOAP_ACTION_AND_ENDPOINT(svc, env, soap_action, endpoint) \
+#define AXIS2_SVC_GET_OP_BY_SOAP_ACTION_AND_ENDPOINT(svc, env, soap_action, endpoint) \
         (svc->ops->get_op_by_soap_action_and_endpoint(svc, env, soap_action, endpoint))
 
 #define AXIS2_SVC_GET_AXIS2_SVC_NAME(svc, env) \

Modified: webservices/axis2/trunk/c/include/axis2_svc_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc_ctx.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc_ctx.h Tue Dec 13 00:24:29 2005
@@ -94,7 +94,7 @@
 #define AXIS2_SVC_CTX_GET_SVC_ID(svc_ctx, env) ((svc_ctx)->ops->get_svc_id(svc_ctx, env))
 #define AXIS2_SVC_CTX_GET_SVC(svc_ctx, env) ((svc_ctx)->ops->get_svc(svc_ctx, env))
 #define AXIS2_SVC_CTX_GET_CONF_CTX(svc_ctx, env) ((svc_ctx)->ops->get_conf_ctx(svc_ctx, env))
-#define AXIS2_SVC_CTX_CREATE_OPERATION_CTX(svc_ctx, env, qname) ((svc_ctx)->ops->create_op_ctx(svc_ctx, env, qname))
+#define AXIS2_SVC_CTX_CREATE_OP_CTX(svc_ctx, env, qname) ((svc_ctx)->ops->create_op_ctx(svc_ctx, env, qname))
     
 /************************** End of function macros ****************************/    
 

Modified: webservices/axis2/trunk/c/include/axis2_transport_in_desc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_transport_in_desc.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_transport_in_desc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_transport_in_desc.h Tue Dec 13 00:24:29 2005
@@ -177,10 +177,10 @@
 #define AXIS2_TRANSPORT_IN_DESC_SET_RECV(transport_in_desc, env, recv) \
 		((transport_in_desc->ops)->set_recv (transport_in_desc, env, recv)) 
 
-#define AXIS2_TRANSPORT_IN_DESC_GET_INPHASE(transport_in_desc, env) \
+#define AXIS2_TRANSPORT_IN_DESC_GET_IN_PHASE(transport_in_desc, env) \
 		((transport_in_desc->ops)->get_in_phase (transport_in_desc, env)) 
         
-#define AXIS2_TRANSPORT_IN_DESC_SET_INPHASE(transport_in_desc, env, in_phase) \
+#define AXIS2_TRANSPORT_IN_DESC_SET_IN_PHASE(transport_in_desc, env, in_phase) \
 		((transport_in_desc->ops)->set_in_phase (transport_in_desc, env, in_phase)) 
 
 #define AXIS2_TRANSPORT_IN_DESC_GET_FAULTPHASE(transport_in_desc, env) \

Modified: webservices/axis2/trunk/c/include/axis2_transport_out_desc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_transport_out_desc.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_transport_out_desc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_transport_out_desc.h Tue Dec 13 00:24:29 2005
@@ -177,10 +177,10 @@
 #define AXIS2_TRANSPORT_OUT_DESC_SET_SENDER(transport_out_desc, env, sender) \
 		((transport_out_desc->ops)->set_sender (transport_out_desc, env, sender)) 
 
-#define AXIS2_TRANSPORT_OUT_DESC_GET_OUTPHASE(transport_out_desc, env) \
+#define AXIS2_TRANSPORT_OUT_DESC_GET_OUT_PHASE(transport_out_desc, env) \
 		((transport_out_desc->ops)->get_out_phase (transport_out_desc, env)) 
         
-#define AXIS2_TRANSPORT_OUT_DESC_SET_OUTPHASE(transport_out_desc, env, out_phase) \
+#define AXIS2_TRANSPORT_OUT_DESC_SET_OUT_PHASE(transport_out_desc, env, out_phase) \
 		((transport_out_desc->ops)->set_out_phase (transport_out_desc, env, out_phase)) 
 
 #define AXIS2_TRANSPORT_OUT_DESC_GET_FAULTPHASE(transport_out_desc, env) \

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_binding.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_binding.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_binding.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_binding.h Tue Dec 13 00:24:29 2005
@@ -234,16 +234,16 @@
 #define AXIS2_WSDL_BINDING_SET_BINDING_FAULTS(wsdl_binding, env, faults) \
 		((wsdl_binding->ops)->set_binding_faults (wsdl_binding, env, faults))
 
-#define AXIS2_WSDL_BINDING_GET_BINDING_OPERATIONS(wsdl_binding, env) \
+#define AXIS2_WSDL_BINDING_GET_BINDING_OPS(wsdl_binding, env) \
 		((wsdl_binding->ops)->get_binding_ops (wsdl_binding, env))
 
-#define AXIS2_WSDL_BINDING_SET_BINDING_OPERATIONS(wsdl_binding, env, ops) \
+#define AXIS2_WSDL_BINDING_SET_BINDING_OPS(wsdl_binding, env, ops) \
 		((wsdl_binding->ops)->set_binding_ops (wsdl_binding, env, ops)) 
         
-#define AXIS2_WSDL_BINDING_ADD_BINDING_OPERATION(wsdl_binding, env, op) \
+#define AXIS2_WSDL_BINDING_ADD_BINDING_OP(wsdl_binding, env, op) \
 		((wsdl_binding->ops)->add_binding_op (wsdl_binding, env, op))
 
-#define AXIS2_WSDL_BINDING_GET_BINDING_OPERATION(wsdl_binding, env) \
+#define AXIS2_WSDL_BINDING_GET_BINDING_OP(wsdl_binding, env) \
 		((wsdl_binding->ops)->get_binding_op (wsdl_binding, env)) 
 
 #define AXIS2_WSDL_BINDING_ADD_BINDING_FAULT(wsdl_binding, env, op) \

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_binding_op.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_binding_op.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_binding_op.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_binding_op.h Tue Dec 13 00:24:29 2005
@@ -1,5 +1,5 @@
-#ifndef AXIS2_WSDL_BINDING_OPERATION_H
-#define AXIS2_WSDL_BINDING_OPERATION_H
+#ifndef AXIS2_WSDL_BINDING_OP_H
+#define AXIS2_WSDL_BINDING_OP_H
 
 /**
  * @file axis2_wsdl_binding_op.h
@@ -183,50 +183,50 @@
 
 /**************************** Start of function macros ************************/
 
-#define AXIS2_WSDL_BINDING_OPERATION_FREE(wsdl_binding_op, env) \
+#define AXIS2_WSDL_BINDING_OP_FREE(wsdl_binding_op, env) \
 		((wsdl_binding_op->ops)->free (wsdl_binding_op, env))
 
-#define AXIS2_WSDL_BINDING_OPERATION_SET_INPUT(wsdl_binding_op, env, \
+#define AXIS2_WSDL_BINDING_OP_SET_INPUT(wsdl_binding_op, env, \
 		inut) \
 		((wsdl_binding_op->ops)->set_input(wsdl_binding_op , env, \
             input)
 	
-#define AXIS2_WSDL_BINDING_OPERATION_GET_OPERATION(wsdl_binding_op, env) \
+#define AXIS2_WSDL_BINDING_OP_GET_OP(wsdl_binding_op, env) \
 		((wsdl_binding_op->ops)->get_op(wsdl_binding_op, env))
 
-#define AXIS2_WSDL_BINDING_OPERATION_SET_OPERATION(wsdl_binding_op, env, \
+#define AXIS2_WSDL_BINDING_OP_SET_OP(wsdl_binding_op, env, \
 		key, op) \
 		((wsdl_binding_op->ops)->set_op(wsdl_binding_op, env,\
             key, op))
 		
-#define AXIS2_WSDL_BINDING_OPERATION_GET_OUTPUT(wsdl_binding_op, env) \
+#define AXIS2_WSDL_BINDING_OP_GET_OUTPUT(wsdl_binding_op, env) \
 		((wsdl_binding_op->ops)->get_output(wsdl_binding_op, env))
         
-#define AXIS2_WSDL_BINDING_OPERATION_SET_OUTPUT(wsdl_binding_op, env, output) \
+#define AXIS2_WSDL_BINDING_OP_SET_OUTPUT(wsdl_binding_op, env, output) \
 		((wsdl_binding_op->ops)->set_output(wsdl_binding_op, env, output))
 
-#define AXIS2_WSDL_BINDING_OPERATION_GET_QNAME(wsdl_binding_op, env) \
+#define AXIS2_WSDL_BINDING_OP_GET_QNAME(wsdl_binding_op, env) \
 		((wsdl_binding_op->ops)->get_qname(wsdl_binding_op, env))
         
-#define AXIS2_WSDL_BINDING_OPERATION_SET_QNAME(wsdl_binding_op, env, qname) \
+#define AXIS2_WSDL_BINDING_OP_SET_QNAME(wsdl_binding_op, env, qname) \
 		((wsdl_binding_op->ops)->set_qname(wsdl_binding_op, env, qname))
 
-#define AXIS2_WSDL_BINDING_OPERATION_ADD_INFAULT(wsdl_binding_op, env, in_fault) \
+#define AXIS2_WSDL_BINDING_OP_ADD_IN_FAULT(wsdl_binding_op, env, in_fault) \
 		((wsdl_binding_op->ops)->add_in_fault(wsdl_binding_op, env, in_fault))
         
-#define AXIS2_WSDL_BINDING_OPERATION_ADD_OUTFAULT(wsdl_binding_op, env, out_fault) \
+#define AXIS2_WSDL_BINDING_OP_ADD_OUTFAULT(wsdl_binding_op, env, out_fault) \
 		((wsdl_binding_op->ops)->add_out_fault(wsdl_binding_op, env, out_fault))
 
-#define AXIS2_WSDL_BINDING_OPERATION_GET_INFAULTS(wsdl_binding_op, env) \
+#define AXIS2_WSDL_BINDING_OP_GET_IN_FAULTS(wsdl_binding_op, env) \
 		((wsdl_binding_op->ops)->get_in_faults(wsdl_binding_op, env))
         
-#define AXIS2_WSDL_BINDING_OPERATION_SET_INFAULTS(wsdl_binding_op, env, in_faults) \
+#define AXIS2_WSDL_BINDING_OP_SET_IN_FAULTS(wsdl_binding_op, env, in_faults) \
 		((wsdl_binding_op->ops)->set_in_faults(wsdl_binding_op, env, in_faults))        
 
-#define AXIS2_WSDL_BINDING_OPERATION_GET_OUTFAULTS(wsdl_binding_op, env) \
+#define AXIS2_WSDL_BINDING_OP_GET_OUTFAULTS(wsdl_binding_op, env) \
 		((wsdl_binding_op->ops)->get_out_faults(wsdl_binding_op, env))
         
-#define AXIS2_WSDL_BINDING_OPERATION_SET_OUTFAULTS(wsdl_binding_op, env, out_faults) \
+#define AXIS2_WSDL_BINDING_OP_SET_OUTFAULTS(wsdl_binding_op, env, out_faults) \
 		((wsdl_binding_op->ops)->set_out_faults(wsdl_binding_op, env, out_faults))
      
 /**************************** End of function macros **************************/
@@ -236,4 +236,4 @@
 }
 #endif
 
-#endif /*AXIS2_WSDL_BINDING_OPERATION_H*/
+#endif /*AXIS2_WSDL_BINDING_OP_H*/

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_interface.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_interface.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_interface.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_interface.h Tue Dec 13 00:24:29 2005
@@ -232,7 +232,7 @@
 #define AXIS2_WSDL_INTERFACE_FREE(wsdl_interface, env) \
 		((wsdl_interface->ops)->free (wsdl_interface, env))
 
-#define AXIS2_WSDL_INTERFACE_GET_DEFINED_OPERATIONS(wsdl_interface, env) \
+#define AXIS2_WSDL_INTERFACE_GET_DEFINED_OPS(wsdl_interface, env) \
 		((wsdl_interface->ops)->get_defined_ops (wsdl_interface, env))
 
 #define AXIS2_WSDL_INTERFACE_GET_FAULTS(wsdl_interface, env) \
@@ -241,10 +241,10 @@
 #define AXIS2_WSDL_INTERFACE_GET_NAME(wsdl_interface, env) \
 		((wsdl_interface->ops)->get_name (wsdl_interface, env))
 
-#define AXIS2_WSDL_INTERFACE_GET_OPERATIONS(wsdl_interface, env) \
+#define AXIS2_WSDL_INTERFACE_GET_OPS(wsdl_interface, env) \
 		((wsdl_interface->ops)->get_ops (wsdl_interface, env))
 
-#define AXIS2_WSDL_INTERFACE_GET_OPERATION(wsdl_interface, env, nc_name) \
+#define AXIS2_WSDL_INTERFACE_GET_OP(wsdl_interface, env, nc_name) \
 		((wsdl_interface->ops)->get_op (wsdl_interface, env, nc_name))
         
 #define AXIS2_WSDL_INTERFACE_GET_SUPER_INTERFACES(wsdl_interface, env) \
@@ -262,10 +262,10 @@
 #define AXIS2_WSDL_INTERFACE_SET_NAME(wsdl_interface, env, name) \
 		((wsdl_interface->ops)->set_name (wsdl_interface, env, name))
         
-#define AXIS2_WSDL_INTERFACE_SET_OPERATIONS(wsdl_interface, env, list) \
+#define AXIS2_WSDL_INTERFACE_SET_OPS(wsdl_interface, env, list) \
 		((wsdl_interface->ops)->set_ops (wsdl_interface, env, list))
 
-#define AXIS2_WSDL_INTERFACE_SET_OPERATION(wsdl_interface, env, op, optr_type) \
+#define AXIS2_WSDL_INTERFACE_SET_OP(wsdl_interface, env, op, optr_type) \
 		((wsdl_interface->ops)->set_op (wsdl_interface, env, op, optr_type))
 
 #define AXIS2_WSDL_INTERFACE_SET_SUPER_INTERFACES(wsdl_interface, env, list) \

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_op.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_op.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_op.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_op.h Tue Dec 13 00:24:29 2005
@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#ifndef AXIS2_WSDL_OPERATION_H
-#define AXIS2_WSDL_OPERATION_H
+#ifndef AXIS2_WSDL_OP_H
+#define AXIS2_WSDL_OP_H
 
 /**
  * @file axis2_wsdl_op.h
@@ -252,64 +252,64 @@
 
 /**************************** Start of function macros ************************/
 
-#define AXIS2_WSDL_OPERATION_FREE(wsdl_op, env) \
+#define AXIS2_WSDL_OP_FREE(wsdl_op, env) \
 		((wsdl_op->ops)->free (wsdl_op, env))
 	
-#define AXIS2_WSDL_OPERATION_GET_MSG_EXCHANGE_PATTERN(wsdl_op, env) \
+#define AXIS2_WSDL_OP_GET_MSG_EXCHANGE_PATTERN(wsdl_op, env) \
 		((wsdl_op->ops)->get_msg_exchange_pattern(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_MSG_EXCHANGE_PATTERN(wsdl_op, env, pattern) \
+#define AXIS2_WSDL_OP_SET_MSG_EXCHANGE_PATTERN(wsdl_op, env, pattern) \
 		((wsdl_op->ops)->set_msg_exchange_pattern(wsdl_op, env, pattern))
 		
-#define AXIS2_WSDL_OPERATION_GET_NAME(wsdl_op, env) \
+#define AXIS2_WSDL_OP_GET_NAME(wsdl_op, env) \
 		((wsdl_op->ops)->get_name(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_NAME(wsdl_op, env, name) \
+#define AXIS2_WSDL_OP_SET_NAME(wsdl_op, env, name) \
 		((wsdl_op->ops)->set_name(wsdl_op, env, name))
 		
-#define AXIS2_WSDL_OPERATION_SET_STYLE(wsdl_op, env, style) \
+#define AXIS2_WSDL_OP_SET_STYLE(wsdl_op, env, style) \
 		((wsdl_op->ops)->set_style(wsdl_op, env, style))
 		
-#define AXIS2_WSDL_OPERATION_GET_STYLE(wsdl_op, env) \
+#define AXIS2_WSDL_OP_GET_STYLE(wsdl_op, env) \
 		((wsdl_op->ops)->get_style(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_GET_INFAULTS(wsdl_op, env) \
+#define AXIS2_WSDL_OP_GET_IN_FAULTS(wsdl_op, env) \
 		((wsdl_op->ops)->get_in_faults(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_INFAULTS(wsdl_op, env, in_faults) \
+#define AXIS2_WSDL_OP_SET_IN_FAULTS(wsdl_op, env, in_faults) \
 		((wsdl_op->ops)->set_in_faults(wsdl_op, env, in_faults))
 
-#define AXIS2_WSDL_OPERATION_GET_INPUT_MSG(wsdl_op, env) \
+#define AXIS2_WSDL_OP_GET_INPUT_MSG(wsdl_op, env) \
 		((wsdl_op->ops)->get_input_msg(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_INPUT_MSG(wsdl_op, env, input_msg) \
+#define AXIS2_WSDL_OP_SET_INPUT_MSG(wsdl_op, env, input_msg) \
 		((wsdl_op->ops)->set_input_msg(wsdl_op, env, input_msg))		
 
-#define AXIS2_WSDL_OPERATION_GET_OUTFAULTS(wsdl_op, env) \
+#define AXIS2_WSDL_OP_GET_OUTFAULTS(wsdl_op, env) \
 		((wsdl_op->ops)->get_out_faults(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_OUTFAULTS(wsdl_op, env, out_faults) \
+#define AXIS2_WSDL_OP_SET_OUTFAULTS(wsdl_op, env, out_faults) \
 		((wsdl_op->ops)->set_out_faults(wsdl_op, env, out_faults))
 
-#define AXIS2_WSDL_OPERATION_GET_OUTPUT_MSG(wsdl_op, env) \
+#define AXIS2_WSDL_OP_GET_OUTPUT_MSG(wsdl_op, env) \
 		((wsdl_op->ops)->get_output_msg(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_OUTPUT_MSG(wsdl_op, env, output_msg) \
+#define AXIS2_WSDL_OP_SET_OUTPUT_MSG(wsdl_op, env, output_msg) \
 		((wsdl_op->ops)->set_output_msg(wsdl_op, env, output_msg))
 
-#define AXIS2_WSDL_OPERATION_IS_SAFE(wsdl_op, env) \
+#define AXIS2_WSDL_OP_IS_SAFE(wsdl_op, env) \
 		((wsdl_op->ops)->is_safe(wsdl_op, env))
 		
-#define AXIS2_WSDL_OPERATION_SET_SAFETY(wsdl_op, env, safe) \
+#define AXIS2_WSDL_OP_SET_SAFETY(wsdl_op, env, safe) \
 		((wsdl_op->ops)->set_safety(wsdl_op, env, safe))
         
-#define AXIS2_WSDL_OPERATION_GET_TARGET_NAMESPACE(wsdl_op, env) \
+#define AXIS2_WSDL_OP_GET_TARGET_NAMESPACE(wsdl_op, env) \
 		((wsdl_op->ops)->get_target_namespace(wsdl_op, env))        
 
-#define AXIS2_WSDL_OPERATION_ADD_INFAULT(wsdl_op, env, in_fault) \
+#define AXIS2_WSDL_OP_ADD_IN_FAULT(wsdl_op, env, in_fault) \
 		((wsdl_op->ops)->add_in_fault(wsdl_op, env, in_fault))
 		
-#define AXIS2_WSDL_OPERATION_ADD_OUTFAULT(wsdl_op, env, out_fault) \
+#define AXIS2_WSDL_OP_ADD_OUTFAULT(wsdl_op, env, out_fault) \
 		((wsdl_op->ops)->add_out_fault(wsdl_op, env, out_fault))
 
 /**************************** End of function macros **************************/
@@ -318,4 +318,4 @@
 #ifdef __cplusplus
 }
 #endif
-#endif /* AXIS2_WSDL_OPERATION_H  */
+#endif /* AXIS2_WSDL_OP_H  */

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_soap_op.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_soap_op.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_soap_op.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_soap_op.h Tue Dec 13 00:24:29 2005
@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#ifndef AXIS2_WSDL_SOAP_OPERATION_H
-#define AXIS2_WSDL_SOAP_OPERATION_H
+#ifndef AXIS2_WSDL_SOAP_OP_H
+#define AXIS2_WSDL_SOAP_OP_H
 
 /**
  * @file axis2_wsdl_soap_op.h
@@ -103,19 +103,19 @@
 
 /*************************** Function macros **********************************/
 
-#define AXIS2_WSDL_SOAP_OPERATION_FREE(extensible_element, env) \
+#define AXIS2_WSDL_SOAP_OP_FREE(extensible_element, env) \
 		((extensible_element->ops)->free (extensible_element, env))
 
-#define AXIS2_WSDL_SOAP_OPERATION_GET_STYLE(extensible_element, env) \
+#define AXIS2_WSDL_SOAP_OP_GET_STYLE(extensible_element, env) \
 		((extensible_element->ops)->get_style (extensible_element, env))
 
-#define AXIS2_WSDL_SOAP_OPERATION_SET_STYLE(extensible_element, env, style) \
+#define AXIS2_WSDL_SOAP_OP_SET_STYLE(extensible_element, env, style) \
 		((extensible_element->ops)->set_style (extensible_element, env, style))
 
-#define AXIS2_WSDL_SOAP_OPERATION_GET_SOAP_ACTION(extensible_element, env) \
+#define AXIS2_WSDL_SOAP_OP_GET_SOAP_ACTION(extensible_element, env) \
 		((extensible_element->ops)->get_soap_action (extensible_element, env))
 
-#define AXIS2_WSDL_SOAP_OPERATION_SET_SOAP_ACTION(extensible_element, env, soap_action) \
+#define AXIS2_WSDL_SOAP_OP_SET_SOAP_ACTION(extensible_element, env, soap_action) \
 		((extensible_element->ops)->set_soap_action (extensible_element, env, soap_action))       
 
 /*************************** End of function macros ***************************/
@@ -125,4 +125,4 @@
 #ifdef __cplusplus
 }
 #endif
-#endif  /* AXIS2_WSDL_SOAP_OPERATION_H */
+#endif  /* AXIS2_WSDL_SOAP_OP_H */

Modified: webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/conf_ctx.c Tue Dec 13 00:24:29 2005
@@ -430,7 +430,7 @@
         if (ctx)
         {
             axis2_op_ctx_t *op_ctx = (axis2_op_ctx_t*) ctx;
-            AXIS2_OPERATION_CTX_INIT(op_ctx, env, conf);
+            AXIS2_OP_CTX_INIT(op_ctx, env, conf);
         }
     }
 
@@ -595,14 +595,14 @@
     }
     
     /* when you come here op context MUST already been assigned to the message context */
-    op_ctx = AXIS2_MSG_CTX_GET_OPERATION_CTX(msg_ctx, env);
+    op_ctx = AXIS2_MSG_CTX_GET_OP_CTX(msg_ctx, env);
     if (!op_ctx)
     {
         AXIS2_ERROR_SET((*env)->error, AXIS2_ERROR_INVALID_STATE_MSG_CTX, AXIS2_FAILURE);
         return NULL;
     }
     
-    AXIS2_OPERATION_CTX_SET_PARENT(op_ctx, env, svc_ctx);
+    AXIS2_OP_CTX_SET_PARENT(op_ctx, env, svc_ctx);
     AXIS2_MSG_CTX_SET_SVC_CTX(msg_ctx, env, svc_ctx);
     AXIS2_MSG_CTX_SET_SVC_GRP_CTX(msg_ctx, env, svc_grp_ctx);
     return svc_grp_ctx;

Modified: webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/msg_ctx.c Tue Dec 13 00:24:29 2005
@@ -738,28 +738,28 @@
     
     /*if (msg_ctx_impl->transport_in_desc_qname)
     {
-        msg_ctx_impl->transport_in_desc = AXIS2_ENGINE_CONFIG_GET_TRANSPORT_IN(conf, env, msg_ctx_impl->transport_in_desc_qname);
+        msg_ctx_impl->transport_in_desc = AXIS2_CONF_GET_TRANSPORT_IN(conf, env, msg_ctx_impl->transport_in_desc_qname);
     }*/
     
     /*if (msg_ctx_impl->transport_out_desc_qname)
     {
-        msg_ctx_impl->transport_out_desc = AXIS2_ENGINE_CONFIG_GET_TRANSPORT_IN(conf, env, msg_ctx_impl->transport_out_desc_qname);
+        msg_ctx_impl->transport_out_desc = AXIS2_CONF_GET_TRANSPORT_IN(conf, env, msg_ctx_impl->transport_out_desc_qname);
     }*/
     
     if (msg_ctx_impl->svc_grp_id)
     {
-        /*msg_ctx_impl->svc_grp = AXIS2_ENGINE_CONFIG_GET_SVC_GRP(conf, env, msg_ctx_impl->svc_grp_id);*/
+        /*msg_ctx_impl->svc_grp = AXIS2_CONF_GET_SVC_GRP(conf, env, msg_ctx_impl->svc_grp_id);*/
     }
     
     if (msg_ctx_impl->svc_qname)
     {
-        /*msg_ctx_impl->svc = AXIS2_ENGINE_CONFIG_GET_SVC(conf, env, AXIS2_QNAME_GET_LOCALPART(msg_ctx_impl->svc_qname, env));*/
+        /*msg_ctx_impl->svc = AXIS2_CONF_GET_SVC(conf, env, AXIS2_QNAME_GET_LOCALPART(msg_ctx_impl->svc_qname, env));*/
     }
     
     if (msg_ctx_impl->op_qname)
     {
         /*if (msg_ctx_impl->svc)
-            msg_ctx_impl->op = AXIS2_SVC_GET_OPERATION_WITH_QNAME(msg_ctx_impl->svc, env, msg_ctx_impl->op_qname);*/
+            msg_ctx_impl->op = AXIS2_SVC_GET_OP_WITH_QNAME(msg_ctx_impl->svc, env, msg_ctx_impl->op_qname);*/
     }
     
     return AXIS2_SUCCESS;
@@ -1257,13 +1257,13 @@
         
         if (msg_ctx_impl->svc_ctx)
         {
-            /*if (!(AXIS2_OPERATION_CTX_GET_PARENT(msg_ctx_impl->op_ctx, env)))
+            /*if (!(AXIS2_OP_CTX_GET_PARENT(msg_ctx_impl->op_ctx, env)))
             {
-                AXIS2_OPERATION_CTX_SET_PARENT(msg_ctx_impl->op_ctx, env, msg_ctx_impl->svc_ctx);
+                AXIS2_OP_CTX_SET_PARENT(msg_ctx_impl->op_ctx, env, msg_ctx_impl->svc_ctx);
             }*/
         }
         axis2_msg_ctx_set_parent(msg_ctx, env, op_ctx);
-        /*axis2_msg_ctx_set_op(msg_ctx, env, AXIS2_OPERATION_CTX_GET_OPRATION(op_ctx, env));    */
+        /*axis2_msg_ctx_set_op(msg_ctx, env, AXIS2_OP_CTX_GET_OPRATION(op_ctx, env));    */
     }
     return AXIS2_SUCCESS;
 }
@@ -1384,8 +1384,8 @@
         
         if(msg_ctx_impl->op_ctx)
         {
-            /*if (!AXIS2_OPERATION_CTX_GET_PARENT(msg_ctx_impl->op_ctx, env))
-                AXIS2_OPERATION_CTX_SET_PARENT(msg_ctx_impl->op_ctx, env, svc_ctx);*/
+            /*if (!AXIS2_OP_CTX_GET_PARENT(msg_ctx_impl->op_ctx, env))
+                AXIS2_OP_CTX_SET_PARENT(msg_ctx_impl->op_ctx, env, svc_ctx);*/
         }
         /*set_svc(msg_ctx, env, AXIS2_SVC_CTX_GET_SVC(svc_ctx, env);*/
     }
@@ -1435,7 +1435,7 @@
     
     if (msg_ctx_impl->op) 
     {
-        /*param = AXIS2_OPERATION_GET_PARAM(msg_ctx_impl->op, env, key);*/
+        /*param = AXIS2_OP_GET_PARAM(msg_ctx_impl->op, env, key);*/
         if (param)
         {
             return param;
@@ -1463,7 +1463,7 @@
     if (msg_ctx_impl->conf_ctx) 
     {
         /*axis2_conf_t *conf = AXIS2_CONFIG_CTX_GET_CONFIG(msg_ctx_impl->conf_ctx, env);
-        param = AXIS2_ENGINE_CONFIG_GET_PARAM(conf, env, key);*/
+        param = AXIS2_CONF_GET_PARAM(conf, env, key);*/
     }
     
     return param;
@@ -1513,7 +1513,7 @@
     
     if (msg_ctx_impl->op)
     {
-        /*module_config = AXIS2_OPERATION_GET_MODULE_CONFIG(msg_ctx_impl->op, env, qname);*/
+        /*module_config = AXIS2_OP_GET_MODULE_CONFIG(msg_ctx_impl->op, env, qname);*/
         AXIS2_QNAME_FREE(qname, env);
         /*if (module_config) 
         {
@@ -1524,7 +1524,7 @@
             } 
             else 
             {
-                param = AXIS2_OPERATION_GET_PARAM(msg_ctx_impl->op, env, key);
+                param = AXIS2_OP_GET_PARAM(msg_ctx_impl->op, env, key);
                 if (param)
                 {
                     return param;
@@ -1580,7 +1580,7 @@
     /*conf = AXIS2_CONFIG_CTX_GET_CONFIG(msg_ctx_impl->conf_ctx, env);*/
     if (conf)
     {
-        /*module_config = AXIS2_ENGINE_CONFIG_GET_MODULE_CONFIG(conf, env, qname);*/
+        /*module_config = AXIS2_CONF_GET_MODULE_CONFIG(conf, env, qname);*/
         AXIS2_QNAME_FREE(qname, env);
     }    
     
@@ -1593,7 +1593,7 @@
         } 
         else 
         {
-            param = AXIS2_ENGINE_CONFIG_GET_PARAM(conf, env, key);
+            param = AXIS2_CONF_GET_PARAM(conf, env, key);
             if (param)
             {
                 return param;
@@ -1603,7 +1603,7 @@
     
     if (conf)
     {
-        /*module = AXIS2_ENGINE_CONFIG_GET_MODULE(conf, env, qname);*/
+        /*module = AXIS2_CONF_GET_MODULE(conf, env, qname);*/
         AXIS2_QNAME_FREE(qname, env);
     }
     
@@ -1868,7 +1868,7 @@
     if (op)
     {
         AXIS2_INTF_TO_IMPL(msg_ctx)->op = op;
-        AXIS2_INTF_TO_IMPL(msg_ctx)->op_qname = AXIS2_OPERATION_GET_NAME(op, env);
+        AXIS2_INTF_TO_IMPL(msg_ctx)->op_qname = AXIS2_OP_GET_NAME(op, env);
     }
     
     return AXIS2_SUCCESS;

Modified: webservices/axis2/trunk/c/modules/core/context/src/op_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/op_ctx.c?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/op_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/op_ctx.c Tue Dec 13 00:24:29 2005
@@ -128,8 +128,8 @@
     
     if (op_ctx_impl->op)
     {
-        /*op_ctx_impl->op_qname = AXIS2_OPERATION_GET_QNAME(op_ctx_impl->op, env);
-        op_ctx_impl->op_mep = AXIS2_OPERATION_GET_MEP_CONST(op_ctx_impl->op, env);*/
+        /*op_ctx_impl->op_qname = AXIS2_OP_GET_QNAME(op_ctx_impl->op, env);
+        op_ctx_impl->op_mep = AXIS2_OP_GET_MEP_CONST(op_ctx_impl->op, env);*/
     }
     
     axis2_op_ctx_set_parent(&(op_ctx_impl->op_ctx), env, svc_ctx);
@@ -222,11 +222,11 @@
         
         if (svc_name)
         {
-            svc = AXIS2_ENGINE_CONFIG_GET_SVC(conf, env, svc_name);
+            svc = AXIS2_CONF_GET_SVC(conf, env, svc_name);
             
             if (svc)
             {
-               /* op_ctx_impl->op = AXIS2_SVC_GET_OPERATION_WITH_QNAME(svc, env, op_ctx_impl->op_qname);*/
+               /* op_ctx_impl->op = AXIS2_SVC_GET_OP_WITH_QNAME(svc, env, op_ctx_impl->op_qname);*/
             }
         }
     }
@@ -287,7 +287,7 @@
         
     if(op_ctx_impl->op)
     {
-        /*return AXIS2_OPERATION_ADD_MSG_CTX(op_ctx_impl->op, env, msg_ctx, op_ctx);*/
+        /*return AXIS2_OP_ADD_MSG_CTX(op_ctx_impl->op, env, msg_ctx, op_ctx);*/
     }
     
     return AXIS2_SUCCESS;
@@ -401,7 +401,7 @@
         conf_ctx = AXIS2_SVC_CTX_GET_CONF_CTX(op_ctx_impl->parent, env);
         if (conf_ctx)
         {
-            op_ctx_impl->op_ctx_map = AXIS2_CONF_CTX_GET_OPERATION_CTX_MAP(conf_ctx, env);
+            op_ctx_impl->op_ctx_map = AXIS2_CONF_CTX_GET_OP_CTX_MAP(conf_ctx, env);
         }
         op_ctx_impl->svc_qname = AXIS2_SVC_GET_QNAME(op_ctx_impl->parent, env);*/
     }

Modified: webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/svc_ctx.c Tue Dec 13 00:24:29 2005
@@ -181,7 +181,7 @@
     if (svc_ctx_impl->svc_qname)
     {
         axis2_char_t *svc_name = AXIS2_QNAME_GET_LOCALPART(svc_ctx_impl->svc_qname, env);
-        svc_ctx_impl->svc = AXIS2_ENGINE_CONFIG_GET_SVC(conf, env, svc_name);
+        svc_ctx_impl->svc = AXIS2_CONF_GET_SVC(conf, env, svc_name);
     }
     
     return AXIS2_SUCCESS;
@@ -224,7 +224,7 @@
     
     if (svc_ctx_impl->svc)
     {
-        /*op = AXIS2_SVC_GET_OPERATION_WITH_QNAME(svc_ctx_impl->svc, env, qname);
+        /*op = AXIS2_SVC_GET_OP_WITH_QNAME(svc_ctx_impl->svc, env, qname);
         return axis2_op_ctx_create(env, op, svc_ctx);*/
     }
     

Modified: webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c (original)
+++ webservices/axis2/trunk/c/modules/core/context/src/svc_grp_ctx.c Tue Dec 13 00:24:29 2005
@@ -204,7 +204,7 @@
 
     if (svc_grp_ctx_impl->svc_grp_name)
     {        
-        svc_grp_ctx_impl->svc_grp = AXIS2_ENGINE_CONFIG_GET_SVC_GRP(conf, env, svc_grp_ctx_impl->svc_grp_name);
+        svc_grp_ctx_impl->svc_grp = AXIS2_CONF_GET_SVC_GRP(conf, env, svc_grp_ctx_impl->svc_grp_name);
     }
     
     return AXIS2_SUCCESS;

Modified: webservices/axis2/trunk/c/modules/core/deployment/src/phases_info.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/deployment/src/phases_info.c?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/deployment/src/phases_info.c (original)
+++ webservices/axis2/trunk/c/modules/core/deployment/src/phases_info.c Tue Dec 13 00:24:29 2005
@@ -499,16 +499,16 @@
     if(NULL == op_out_faultphases)
         return AXIS2_FAILURE;
     
-    status = AXIS2_OPERATION_SET_REMAINING_PHASES_INFLOW(axis2_opt, env, op_in_phases);
+    status = AXIS2_OP_SET_REMAINING_PHASES_INFLOW(axis2_opt, env, op_in_phases);
     if(AXIS2_FAILURE == status)
         return status;
-    status = AXIS2_OPERATION_SET_PHASES_OUTFLOW(axis2_opt, env, op_out_phases);
+    status = AXIS2_OP_SET_PHASES_OUTFLOW(axis2_opt, env, op_out_phases);
     if(AXIS2_FAILURE == status)
         return status;
-    status = AXIS2_OPERATION_SET_PHASES_IN_FAULT_FLOW(axis2_opt, env, op_in_faultphases);
+    status = AXIS2_OP_SET_PHASES_IN_FAULT_FLOW(axis2_opt, env, op_in_faultphases);
     if(AXIS2_FAILURE == status)
         return status;
-    status = AXIS2_OPERATION_SET_PHASES_OUT_FAULT_FLOW(axis2_opt, env, op_out_faultphases);
+    status = AXIS2_OP_SET_PHASES_OUT_FAULT_FLOW(axis2_opt, env, op_out_faultphases);
     
     return status;
     

Modified: webservices/axis2/trunk/c/modules/core/description/src/axis2_description.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/axis2_description.h?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/axis2_description.h (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/axis2_description.h Tue Dec 13 00:24:29 2005
@@ -58,9 +58,9 @@
 #define MODULEREF_KEY  "MODULEREF_KEY"
 
 /**
- * Field OPERATION_KEY
+ * Field OP_KEY
  */
-#define OPERATION_KEY  "OPERATION_KEY"
+#define OP_KEY  "OP_KEY"
 
 /**
  * Field CLASSLOADER_KEY

Modified: webservices/axis2/trunk/c/modules/core/description/src/module_desc.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/module_desc.c?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/module_desc.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/module_desc.c Tue Dec 13 00:24:29 2005
@@ -285,7 +285,7 @@
             axis2_hash_this (hi, NULL, NULL, &val);
             op = (struct axis2_op *) val;
             if (op)
-                AXIS2_OPERATION_FREE (op, env);
+                AXIS2_OP_FREE (op, env);
             
             val = NULL;
             op = NULL;
@@ -433,7 +433,7 @@
 		module_desc_impl->ops = axis2_hash_make (env);
 	}	
     
-    optr_name = AXIS2_OPERATION_GET_NAME(op, env);
+    optr_name = AXIS2_OP_GET_NAME(op, env);
     if(NULL == optr_name)
     {
         return AXIS2_FAILURE;
@@ -543,7 +543,7 @@
         AXIS2_ERROR_SET((*env)->error, AXIS2_ERROR_INVALID_STATE_MODULE_DESC, AXIS2_FALSE);
         return AXIS2_FALSE;
     }
-    locked = AXIS2_ENGINE_CONFIG_IS_PARAM_LOCKED(module_desc_impl->parent, env, param_name);
+    locked = AXIS2_CONF_IS_PARAM_LOCKED(module_desc_impl->parent, env, param_name);
     
     if(AXIS2_TRUE == locked)
     {

Modified: webservices/axis2/trunk/c/modules/core/description/src/op.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/op.c?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/op.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/op.c Tue Dec 13 00:24:29 2005
@@ -467,7 +467,7 @@
    
 	if(NULL != op_impl->op.wsdl_op)
     {
-        AXIS2_WSDL_OPERATION_FREE(op_impl->op.wsdl_op, env);
+        AXIS2_WSDL_OP_FREE(op_impl->op.wsdl_op, env);
     }
     op_impl->op.wsdl_op = wsdl_op;
        
@@ -499,7 +499,7 @@
     
     if(NULL != op->wsdl_op)
     {
-	    AXIS2_WSDL_OPERATION_FREE(op->wsdl_op, env);
+	    AXIS2_WSDL_OP_FREE(op->wsdl_op, env);
         op->wsdl_op = NULL;
     }
     
@@ -776,7 +776,7 @@
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FAILURE);
 	
-    return AXIS2_WSDL_OPERATION_SET_NAME(op->wsdl_op, env, qname);
+    return AXIS2_WSDL_OP_SET_NAME(op->wsdl_op, env, qname);
 }
     
 axis2_qname_t * AXIS2_CALL
@@ -785,7 +785,7 @@
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, NULL);
 	
-    return AXIS2_WSDL_OPERATION_GET_NAME(op->wsdl_op,
+    return AXIS2_WSDL_OP_GET_NAME(op->wsdl_op,
         env);
 }
 
@@ -797,7 +797,7 @@
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, pattern, AXIS2_FAILURE);
     
-    return AXIS2_WSDL_OPERATION_SET_MSG_EXCHANGE_PATTERN(op->
+    return AXIS2_WSDL_OP_SET_MSG_EXCHANGE_PATTERN(op->
         wsdl_op, env, pattern);
 }
 
@@ -807,7 +807,7 @@
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, NULL);
     
-    return AXIS2_WSDL_OPERATION_GET_MSG_EXCHANGE_PATTERN
+    return AXIS2_WSDL_OP_GET_MSG_EXCHANGE_PATTERN
         (op->wsdl_op, env);
 }
 
@@ -817,7 +817,7 @@
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, NULL);
     
-    return AXIS2_WSDL_OPERATION_GET_STYLE(op->wsdl_op, env);
+    return AXIS2_WSDL_OP_GET_STYLE(op->wsdl_op, env);
 }
 
 axis2_status_t  AXIS2_CALL
@@ -828,7 +828,7 @@
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, style, AXIS2_FAILURE);
     
-    return AXIS2_WSDL_OPERATION_SET_STYLE(op->wsdl_op, env, style);
+    return AXIS2_WSDL_OP_SET_STYLE(op->wsdl_op, env, style);
 }
 
 axis2_status_t AXIS2_CALL
@@ -867,7 +867,7 @@
                 AXIS2_MODULE_DESC_GET_NAME(moduleref, env)))
         {
             AXIS2_ERROR_SET((*env)->error, 
-                AXIS2_ERROR_MODULE_ALREADY_ENGAGED_TO_OPERATION, AXIS2_FAILURE);
+                AXIS2_ERROR_MODULE_ALREADY_ENGAGED_TO_OP, AXIS2_FAILURE);
             return AXIS2_FAILURE;
         }
 
@@ -875,7 +875,7 @@
     pr = axis2_phase_resolver_create(env);
     if(pr)
     {
-        status = AXIS2_PHASE_RESOLVER_ENGAGE_MODULE_TO_OPERATION(pr, env, 
+        status = AXIS2_PHASE_RESOLVER_ENGAGE_MODULE_TO_OP(pr, env, 
             op, moduleref);
         if(AXIS2_FAILURE == status)
         {
@@ -924,7 +924,7 @@
                 AXIS2_MODULE_DESC_GET_NAME(module_name, env)))
         {
             AXIS2_ERROR_SET((*env)->error, 
-                AXIS2_ERROR_MODULE_ALREADY_ENGAGED_TO_OPERATION, AXIS2_FAILURE);
+                AXIS2_ERROR_MODULE_ALREADY_ENGAGED_TO_OP, AXIS2_FAILURE);
             return AXIS2_FAILURE;
         }
 
@@ -1077,7 +1077,7 @@
             phase = NULL;
                
         }
-        AXIS2_WSDL_OPERATION_FREE(op_impl->phases_in_fault_flow, env);
+        AXIS2_WSDL_OP_FREE(op_impl->phases_in_fault_flow, env);
         op_impl->phases_in_fault_flow = NULL;
     }
     
@@ -1110,7 +1110,7 @@
             phase = NULL;
                
         }
-        AXIS2_WSDL_OPERATION_FREE(op_impl->phases_out_fault_flow, env);
+        AXIS2_WSDL_OP_FREE(op_impl->phases_out_fault_flow, env);
         op_impl->phases_out_fault_flow = NULL;
     }
     
@@ -1143,7 +1143,7 @@
             phase = NULL;
                
         }
-        AXIS2_WSDL_OPERATION_FREE(op_impl->phases_outflow, env);
+        AXIS2_WSDL_OP_FREE(op_impl->phases_outflow, env);
         op_impl->phases_outflow = NULL;
     }
     
@@ -1212,7 +1212,7 @@
                                 axis2_env_t **env) 
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, NULL);
-    return AXIS2_WSDL_OPERATION_GET_INFAULTS(op->wsdl_op, env);
+    return AXIS2_WSDL_OP_GET_IN_FAULTS(op->wsdl_op, env);
 }
 
 axis2_status_t AXIS2_CALL
@@ -1223,7 +1223,7 @@
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, in_faults, AXIS2_FAILURE);
     
-    return AXIS2_WSDL_OPERATION_SET_INFAULTS(op->wsdl_op, env, in_faults);
+    return AXIS2_WSDL_OP_SET_IN_FAULTS(op->wsdl_op, env, in_faults);
 }
 
 struct axis2_wsdl_msg_ref *AXIS2_CALL
@@ -1231,7 +1231,7 @@
                                 axis2_env_t **env) 
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, NULL);
-    return AXIS2_WSDL_OPERATION_GET_INPUT_MSG(op->wsdl_op, env);
+    return AXIS2_WSDL_OP_GET_INPUT_MSG(op->wsdl_op, env);
 }
 
 axis2_status_t AXIS2_CALL
@@ -1242,7 +1242,7 @@
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, input_msg, AXIS2_FAILURE);
     
-    return AXIS2_WSDL_OPERATION_SET_INPUT_MSG(op->wsdl_op, env, input_msg);
+    return AXIS2_WSDL_OP_SET_INPUT_MSG(op->wsdl_op, env, input_msg);
 }
 
 axis2_linked_list_t *AXIS2_CALL
@@ -1250,7 +1250,7 @@
                                 axis2_env_t **env) 
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, NULL);
-    return AXIS2_WSDL_OPERATION_GET_OUTFAULTS(op->wsdl_op, env);
+    return AXIS2_WSDL_OP_GET_OUT_FAULTS(op->wsdl_op, env);
 }
 
 axis2_status_t AXIS2_CALL
@@ -1261,7 +1261,7 @@
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, out_faults, AXIS2_FAILURE);
     
-    return AXIS2_WSDL_OPERATION_SET_OUTFAULTS(op->wsdl_op, env, out_faults);
+    return AXIS2_WSDL_OP_SET_OUT_FAULTS(op->wsdl_op, env, out_faults);
 }
 
 struct axis2_wsdl_msg_ref *AXIS2_CALL
@@ -1269,7 +1269,7 @@
                                 axis2_env_t **env) 
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, NULL);
-    return AXIS2_WSDL_OPERATION_GET_OUTPUT_MSG(op->wsdl_op, env);
+    return AXIS2_WSDL_OP_GET_OUTPUT_MSG(op->wsdl_op, env);
 }
 
 axis2_status_t AXIS2_CALL
@@ -1280,7 +1280,7 @@
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, output_msg, AXIS2_FAILURE);
     
-    return AXIS2_WSDL_OPERATION_SET_OUTPUT_MSG(op->wsdl_op, env, output_msg);
+    return AXIS2_WSDL_OP_SET_OUTPUT_MSG(op->wsdl_op, env, output_msg);
 }
 
 axis2_bool_t AXIS2_CALL
@@ -1288,7 +1288,7 @@
                                 axis2_env_t **env) 
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FALSE);
-    return AXIS2_WSDL_OPERATION_IS_SAFE(op->wsdl_op, env);
+    return AXIS2_WSDL_OP_IS_SAFE(op->wsdl_op, env);
 }
 
 axis2_status_t AXIS2_CALL
@@ -1297,7 +1297,7 @@
                                 axis2_bool_t safe) 
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FAILURE);
-    return AXIS2_WSDL_OPERATION_SET_SAFETY(op->wsdl_op, env, safe);
+    return AXIS2_WSDL_OP_SET_SAFETY(op->wsdl_op, env, safe);
 }
 
 axis2_char_t *AXIS2_CALL
@@ -1305,7 +1305,7 @@
                                         axis2_env_t **env) 
 {
     AXIS2_FUNC_PARAM_CHECK(op, env, NULL);
-    return AXIS2_WSDL_OPERATION_GET_TARGET_NAMESPACE(op->wsdl_op,
+    return AXIS2_WSDL_OP_GET_TARGET_NAMESPACE(op->wsdl_op,
         env);
 }
 
@@ -1317,7 +1317,7 @@
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, in_fault, AXIS2_FAILURE);
     
-    return AXIS2_WSDL_OPERATION_ADD_INFAULT(op->wsdl_op, env, in_fault);
+    return AXIS2_WSDL_OP_ADD_IN_FAULT(op->wsdl_op, env, in_fault);
 }
 
 axis2_status_t AXIS2_CALL
@@ -1328,7 +1328,7 @@
     AXIS2_FUNC_PARAM_CHECK(op, env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, out_fault, AXIS2_FAILURE);
     
-    return AXIS2_WSDL_OPERATION_ADD_OUTFAULT(op->wsdl_op, env, out_fault);
+    return AXIS2_WSDL_OP_ADD_OUT_FAULT(op->wsdl_op, env, out_fault);
 }
 
 axis2_status_t AXIS2_CALL
@@ -1383,7 +1383,7 @@
     
     if(op->wsdl_op)
     {
-        AXIS2_WSDL_OPERATION_FREE(op->wsdl_op, env);
+        AXIS2_WSDL_OP_FREE(op->wsdl_op, env);
         op->wsdl_op = NULL;
     }
     

Modified: webservices/axis2/trunk/c/modules/core/description/src/svc.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/svc.c?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================
--- webservices/axis2/trunk/c/modules/core/description/src/svc_grp.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/svc_grp.c Tue Dec 13 00:24:29 2005
@@ -314,7 +314,7 @@
     
     if(NULL != svc_grp_impl->parent)
     {
-        AXIS2_ENGINE_CONFIG_FREE(svc_grp_impl->parent, env);
+        AXIS2_CONF_FREE(svc_grp_impl->parent, env);
         svc_grp_impl->parent = NULL;
     }
     
@@ -537,7 +537,7 @@
     /* checking the locked value of parent */
     if (NULL != parent) 
     {
-        locked =  AXIS2_ENGINE_CONFIG_IS_PARAM_LOCKED(parent, env, param_name);
+        locked =  AXIS2_CONF_IS_PARAM_LOCKED(parent, env, param_name);
     }
     if(locked)
     {
@@ -588,7 +588,7 @@
     
     svc_grp_impl = AXIS2_INTF_TO_IMPL(svc_grp);
     if(svc_grp_impl->parent)
-        AXIS2_ENGINE_CONFIG_FREE(svc_grp_impl->parent, env);
+        AXIS2_CONF_FREE(svc_grp_impl->parent, env);
     svc_grp_impl->parent = parent;
     return AXIS2_SUCCESS;
 }
@@ -641,7 +641,7 @@
     
     if(NULL == phase_resolver) return AXIS2_FAILURE;
         
-    module = AXIS2_ENGINE_CONFIG_GET_MODULE(svc_grp_impl->parent, env, module_name);
+    module = AXIS2_CONF_GET_MODULE(svc_grp_impl->parent, env, module_name);
     if(NULL != module)
     {
         axis2_hash_index_t *index = NULL;
@@ -700,7 +700,7 @@
     svc_grp_impl = AXIS2_INTF_TO_IMPL(svc_grp);
     
     if(NULL != svc_grp_impl->parent)
-        AXIS2_ENGINE_CONFIG_FREE(svc_grp_impl->parent, env);
+        AXIS2_CONF_FREE(svc_grp_impl->parent, env);
     svc_grp_impl->parent = axis2_desc;
     
     return AXIS2_SUCCESS;
--- webservices/axis2/trunk/c/modules/core/description/src/svc.c (original)
+++ webservices/axis2/trunk/c/modules/core/description/src/svc.c Tue Dec 13 00:24:29 2005
@@ -543,7 +543,7 @@
             axis2_hash_this (hi, NULL, NULL, &val);
             opt = (struct axis2_op *) val;
             if (opt)
-               AXIS2_OPERATION_FREE (opt, env);
+               AXIS2_OP_FREE (opt, env);
             
             val = NULL;
             opt = NULL;
@@ -593,11 +593,11 @@
     AXIS2_FUNC_PARAM_CHECK(svc, env, AXIS2_FALSE);
     AXIS2_PARAM_CHECK((*env)->error, axis2_opt, AXIS2_FALSE);
     
-    status = AXIS2_OPERATION_SET_PARENT(axis2_opt, env, svc);
+    status = AXIS2_OP_SET_PARENT(axis2_opt, env, svc);
     if(AXIS2_TRUE ==status)
     {
-        status = AXIS2_WSDL_INTERFACE_SET_OPERATION(axis2_svc_get_svc_interface(svc, env),
-            env, axis2_opt, AXIS2_OPERATION);
+        status = AXIS2_WSDL_INTERFACE_SET_OP(axis2_svc_get_svc_interface(svc, env),
+            env, axis2_opt, AXIS2_OP);
     }
     return status;
 }
@@ -615,8 +615,8 @@
     AXIS2_PARAM_CHECK((*env)->error, op_name, NULL);
     
     op_str = AXIS2_QNAME_GET_LOCALPART(op_name, env);
-    /* commented until AXIS2_WSDL_INTERFACE_GET_ALL_OPERATIONS is implemented
-    all_ops = AXIS2_WSDL_INTERFACE_GET_ALL_OPERATIONS(
+    /* commented until AXIS2_WSDL_INTERFACE_GET_ALL_OPS is implemented
+    all_ops = AXIS2_WSDL_INTERFACE_GET_ALL_OPS(
         axis2_svc_get_svc_interface(svc, env), env);
     opeartion_l = (struct axis2_op) (axis2_hash_get (all_ops, 
         op_str, AXIS2_HASH_KEY_STRING));
@@ -639,7 +639,7 @@
     AXIS2_FUNC_PARAM_CHECK(svc, env, NULL);
     AXIS2_PARAM_CHECK((*env)->error, nc_name, NULL);
     
-    return (axis2_op_t *) axis2_hash_get(AXIS2_WSDL_INTERFACE_GET_OPERATIONS(
+    return (axis2_op_t *) axis2_hash_get(AXIS2_WSDL_INTERFACE_GET_OPS(
         axis2_svc_get_svc_interface(svc, env), env), nc_name, AXIS2_HASH_KEY_STRING);
 }
 
@@ -649,7 +649,7 @@
 {
     AXIS2_FUNC_PARAM_CHECK(svc, env, NULL);
     
-    return AXIS2_WSDL_INTERFACE_GET_OPERATIONS(axis2_svc_get_svc_interface(svc,
+    return AXIS2_WSDL_INTERFACE_GET_OPS(axis2_svc_get_svc_interface(svc,
         env), env);
 }
 	
@@ -779,7 +779,7 @@
     {
         return AXIS2_FALSE;
     }
-    locked =  AXIS2_ENGINE_CONFIG_IS_PARAM_LOCKED(conf_l, env, param_name);
+    locked =  AXIS2_CONF_IS_PARAM_LOCKED(conf_l, env, param_name);
     
     if(AXIS2_TRUE == locked)
     {
@@ -890,7 +890,7 @@
     AXIS2_PARAM_CHECK((*env)->error, module_desc, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK((*env)->error, axis2_config, AXIS2_FAILURE);
     
-    map = AXIS2_MODULE_DESC_GET_OPERATIONS(module_desc, env);
+    map = AXIS2_MODULE_DESC_GET_OPS(module_desc, env);
     pr = axis2_phase_resolver_create_with_config_and_svc(env, axis2_config, svc);
     if(!pr)
     {
@@ -905,7 +905,7 @@
         void *v = NULL;
         axis2_hash_this (index, NULL, NULL, &v);
         axis2_opt = (struct axis2_op *) v;
-        params = AXIS2_OPERATION_GET_PARAMS(axis2_opt, env);
+        params = AXIS2_OP_GET_PARAMS(axis2_opt, env);
         /* Adding wsa-maping into service */
         size = AXIS2_ARRAY_LIST_SIZE(params, env);
         if(AXIS2_TRUE != AXIS2_ERROR_GET_STATUS_CODE((*env)->error))
@@ -930,7 +930,7 @@
             }
                 
         }
-        status = AXIS2_PHASE_RESOLVER_BUILD_MODULE_OPERATION(pr, env, axis2_opt);
+        status = AXIS2_PHASE_RESOLVER_BUILD_MODULE_OP(pr, env, axis2_opt);
         if(AXIS2_FAILURE == status)
         {
             if(pr)
@@ -1006,7 +1006,7 @@
     svc_interface = axis2_svc_get_svc_interface(svc, env);
     if(svc_interface)
     {
-        return AXIS2_WSDL_INTERFACE_GET_OPERATION(svc_interface, env, op_str) ;
+        return AXIS2_WSDL_INTERFACE_GET_OP(svc_interface, env, op_str) ;
     }
     else
         return NULL;
@@ -1208,8 +1208,8 @@
         
     svc_impl = AXIS2_INTF_TO_IMPL(svc);
     
-    type_1 = axis2_qname_create(env, "op", SOAP_11_OPERATION, NULL);
-    binding_ops = AXIS2_WSDL_BINDING_GET_BINDING_OPERATIONS(
+    type_1 = axis2_qname_create(env, "op", SOAP_11_OP, NULL);
+    binding_ops = AXIS2_WSDL_BINDING_GET_BINDING_OPS(
         AXIS2_WSDL_ENDPOINT_GET_BINDING(axis2_svc_get_endpoint(svc, env, endpoint),
             env), env);
     if(NULL == binding_ops)
@@ -1239,11 +1239,11 @@
             type_2 = AXIS2_WSDL_EXTENSIBLE_ELEMENT_GET_TYPE(element->extensible_element, env);
             if(AXIS2_QNAME_EQUALS(type_2, env, type_1))
             {
-                if(0 == AXIS2_STRCMP(AXIS2_WSDL_SOAP_OPERATION_GET_SOAP_ACTION(
+                if(0 == AXIS2_STRCMP(AXIS2_WSDL_SOAP_OP_GET_SOAP_ACTION(
                     element, env), soap_action))
                 {
                     op = (struct axis2_op *) 
-                        AXIS2_WSDL_BINDING_OPERATION_GET_OPERATION(binding_op,
+                        AXIS2_WSDL_BINDING_OP_GET_OP(binding_op,
                             env);
                     count++;    
                 }

Modified: webservices/axis2/trunk/c/modules/core/description/src/svc_grp.c
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/modules/core/description/src/svc_grp.c?rev=356513&r1=356512&r2=356513&view=diff
==============================================================================